(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     33280,        756]
NotebookOptionsPosition[     32153,        714]
NotebookOutlinePosition[     32805,        739]
CellTagsIndexPosition[     32762,        736]
WindowTitle->Phase Plane Plot of the Van der Pol Differential Equation - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Phase Plane Plot of the Van der Pol Differential Equation", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"process", "[", 
    RowBox[{"\[Lambda]", ",", "k", ",", "pt"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Control", "[", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Lambda]", ",", ".2", ",", 
           RowBox[{"Style", "[", "\"\<\[Lambda]\>\"", "]"}]}], "}"}], ",", 
         "0", ",", "2", ",", ".1", ",", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "Normal"}]}], "}"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Control", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}]}], "}"}], ",", ".1", 
         ",", "3", ",", ".1", ",", 
         RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "Normal"}]}], "}"}], "]"}]}], " ", 
     "}"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "Locator"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", 
    RowBox[{"{", "Top", "}"}]}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"process", "[", 
       RowBox[{"\[Lambda]_", ",", "k_", ",", "pt_"}], "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eq", ",", "x", ",", "t", ",", 
          RowBox[{"tmax", "=", "100"}], ",", "sol", ",", "paramPlot", ",", 
          "solPlot", ",", "vData", ",", "x0", ",", "v0", ",", 
          RowBox[{"lableSize", "=", "14"}], ",", "initialConditionsString"}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"eq", "=", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"x", "''"}], "[", "t", "]"}], "-", 
            RowBox[{"\[Lambda]", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], "^", "2"}]}], ")"}], 
             RowBox[{
              RowBox[{"x", "'"}], "[", "t", "]"}]}], "+", 
            RowBox[{"k", " ", 
             RowBox[{"x", "[", "t", "]"}]}]}], "\[Equal]", "0"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"sol", "=", 
          RowBox[{"First", "[", 
           RowBox[{"NDSolve", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"eq", ",", 
               RowBox[{
                RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
                RowBox[{"pt", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", 
                RowBox[{"pt", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", "x", ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"initialConditionsString", "=", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
               "\"\<(0) = \>\"", ",", 
               RowBox[{"NumberForm", "[", 
                RowBox[{
                 RowBox[{"pt", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"3", ",", "2"}], "}"}], ",", 
                 RowBox[{"NumberSigns", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<-\>\"", ",", "\"\<+\>\""}], "}"}]}]}], "]"}], 
               ",", "\"\<   \>\"", ",", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], "'"}], ",", 
               "\"\<(0) = \>\"", ",", 
               RowBox[{"NumberForm", "[", 
                RowBox[{
                 RowBox[{"pt", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"3", ",", "2"}], "}"}], ",", 
                 RowBox[{"NumberSigns", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<-\>\"", ",", "\"\<+\>\""}], "}"}]}]}], 
                "]"}]}], "\[IndentingNewLine]", "}"}], "]"}], ",", 
            "lableSize", ",", 
            RowBox[{"TextAlignment", "\[Rule]", "Center"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"paramPlot", "=", 
          RowBox[{"ParametricPlot", "[", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], ",", 
                RowBox[{
                 RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}], "/.", "sol"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
            
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"{", " ", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], "'"}], ",", 
                    "\"\<(\>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<t\>\"", ",", "Italic"}], "]"}], ",", 
                    "\"\<)\>\""}], "}"}], "]"}], ",", "lableSize"}], "]"}], 
                 ",", "None"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                    "\"\<(\>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<t\>\"", ",", "Italic"}], "]"}], ",", 
                    "\"\<)\>\""}], "}"}], "]"}], ",", "lableSize"}], "]"}], 
                 ",", 
                 RowBox[{"Column", "[", " ", 
                  RowBox[{
                   RowBox[{"{", " ", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<phase plane plot\>\"", ",", "lableSize"}], 
                    "]"}], ",", "initialConditionsString"}], 
                    "\[IndentingNewLine]", "}"}], ",", 
                   RowBox[{"Alignment", "->", "Center"}]}], "]"}]}], "}"}]}], 
              "}"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"270", ",", "220"}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"ImagePadding", "\[Rule]", "40"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotStyle", "->", "Red"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"solPlot", "=", 
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                    "\"\<(\>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<t\>\"", ",", "Italic"}], "]"}], ",", 
                    "\"\<)\>\""}], "}"}], "]"}], ",", "lableSize"}], "]"}], 
                 ",", "None"}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<time\>\"", ",", "lableSize"}], "]"}], ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                    "\"\<(\>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<t\>\"", ",", "Italic"}], "]"}], ",", 
                    "\"\<) versus time\>\""}], "}"}], "]"}], ",", 
                   "lableSize"}], "]"}]}], "}"}]}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
            
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"270", ",", "220"}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"ImagePadding", "\[Rule]", "40"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotStyle", "->", "Red"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Grid", "[", 
          RowBox[{
           RowBox[{"{", " ", 
            RowBox[{"{", 
             RowBox[{"paramPlot", ",", "solPlot"}], " ", "}"}], "}"}], ",", 
           RowBox[{"Frame", "\[Rule]", "None"}], ",", 
           RowBox[{"Spacings", "\[Rule]", "0"}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}]}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4484217703125*^9, 3.448421797*^9}, {
   3.448421839234375*^9, 3.448421873484375*^9}, {3.448421944359375*^9, 
   3.448421951046875*^9}, {3.448422154890625*^9, 3.44842219046875*^9}, {
   3.448422240109375*^9, 3.44842230728125*^9}, {3.4484223650625*^9, 
   3.448422381828125*^9}, {3.44842242440625*^9, 3.44842244771875*^9}, {
   3.44842248853125*^9, 3.44842249071875*^9}, {3.448422593875*^9, 
   3.448422597125*^9}, {3.4484226509375*^9, 3.448422653828125*^9}, {
   3.44842314253125*^9, 3.44842315353125*^9}, {3.448424133796875*^9, 
   3.44842415771875*^9}, {3.448424299421875*^9, 3.4484243983125*^9}, 
   3.4484244294375*^9, {3.44842450878125*^9, 3.448424648359375*^9}, {
   3.44842467953125*^9, 3.448424680328125*^9}, {3.4484251416875*^9, 
   3.448425231*^9}, {3.44842526425*^9, 3.44842529121875*^9}, 
   3.448425325796875*^9, {3.448425361609375*^9, 3.4484254638125*^9}, {
   3.44842551746875*^9, 3.44842562696875*^9}, {3.448425668765625*^9, 
   3.448425671296875*^9}, {3.4484257856875*^9, 3.448425843640625*^9}, {
   3.448425881453125*^9, 3.448425882875*^9}, {3.448425972078125*^9, 
   3.4484259744375*^9}, {3.4484260070625*^9, 3.448426052640625*^9}, {
   3.448426103953125*^9, 3.448426332453125*^9}, {3.448426378921875*^9, 
   3.4484265921875*^9}, {3.448426624515625*^9, 3.4484266839375*^9}, {
   3.448426724046875*^9, 3.44842675509375*^9}, {3.44842682334375*^9, 
   3.448426958671875*^9}, {3.44842699675*^9, 3.448427006390625*^9}, {
   3.448427079609375*^9, 3.448427131078125*^9}, 3.44842717996875*^9, {
   3.4484279630625*^9, 3.448428123578125*^9}, {3.448428263734375*^9, 
   3.4484282645*^9}, {3.4484283945625*^9, 3.4484284519375*^9}, {
   3.44842850984375*^9, 3.44842852403125*^9}, {3.448428578859375*^9, 
   3.44842861025*^9}, {3.44842865859375*^9, 3.448428662921875*^9}, {
   3.448429697046875*^9, 3.448429785765625*^9}, {3.44842982178125*^9, 
   3.448429922*^9}, {3.44842995784375*^9, 3.44842999796875*^9}, 
   3.44843056775*^9, {3.448896954894834*^9, 3.448897008880232*^9}, 
   3.448908248387268*^9, {3.448908323262748*^9, 3.4489083249033833`*^9}, {
   3.448908438325984*^9, 3.4489084691074314`*^9}, {3.448908514529597*^9, 
   3.4489086354834957`*^9}, {3.448908924532221*^9, 3.4489089295635033`*^9}, 
   3.4489089605637016`*^9, {3.4489090796269636`*^9, 3.448909080470719*^9}, 
   3.448916190969351*^9, {3.4490215710625*^9, 3.44902168934375*^9}, 
   3.449021779765625*^9, {3.44902190821875*^9, 3.44902193771875*^9}, {
   3.449021971015625*^9, 3.44902199565625*^9}, {3.44902203184375*^9, 
   3.4490220325*^9}, {3.44902206534375*^9, 3.4490220695625*^9}, {
   3.449022111703125*^9, 3.44902211628125*^9}, {3.4490257219375*^9, 
   3.449025733359375*^9}, {3.44902687790625*^9, 3.449026949984375*^9}, {
   3.449026985296875*^9, 3.449026988984375*^9}, {3.449027024890625*^9, 
   3.44902703203125*^9}, {3.4490270808125*^9, 3.449027091390625*^9}, 
   3.44902712325*^9, 3.449027198390625*^9, {3.44902729528125*^9, 
   3.44902733915625*^9}, {3.449027369609375*^9, 3.4490273826875*^9}, {
   3.449027701*^9, 3.44902770253125*^9}, {3.4490277861875*^9, 
   3.449027869375*^9}, {3.44902796609375*^9, 3.44902796990625*^9}, {
   3.449028478796875*^9, 3.4490285479375*^9}, {3.44902860565625*^9, 
   3.449028612125*^9}, {3.4490286446875*^9, 3.449028661921875*^9}, {
   3.449028872328125*^9, 3.449028876546875*^9}, {3.44902891534375*^9, 
   3.449028932234375*^9}, {3.449028976484375*^9, 3.449028980140625*^9}, {
   3.4490290881875*^9, 3.449029125828125*^9}, {3.44902918075*^9, 
   3.44902922990625*^9}, {3.44902947753125*^9, 3.4490295060625*^9}, {
   3.449029542171875*^9, 3.449029576375*^9}, {3.44902961815625*^9, 
   3.44902976840625*^9}, {3.4490300796875*^9, 3.4490301068125*^9}, {
   3.449030190859375*^9, 3.44903021271875*^9}, {3.44903025490625*^9, 
   3.449030293*^9}, {3.44903041384375*^9, 3.449030426984375*^9}, {
   3.449030459984375*^9, 3.44903046321875*^9}, {3.449030589640625*^9, 
   3.4490306099375*^9}, {3.449030651078125*^9, 3.44903067603125*^9}, {
   3.449030752671875*^9, 3.449030837703125*^9}, {3.44903092575*^9, 
   3.44903105528125*^9}, {3.44903109065625*^9, 3.449031174609375*^9}, {
   3.449031241671875*^9, 3.449031250546875*^9}, {3.449031362125*^9, 
   3.44903136878125*^9}, {3.44903141775*^9, 3.449031449796875*^9}, {
   3.4490314844375*^9, 3.449031536671875*^9}, {3.449031711734375*^9, 
   3.44903179446875*^9}, {3.449031824703125*^9, 3.44903184553125*^9}, {
   3.449031908125*^9, 3.449031908625*^9}, {3.44903193896875*^9, 
   3.4490319729375*^9}, {3.44903201234375*^9, 3.449032099046875*^9}, {
   3.449032168421875*^9, 3.449032240984375*^9}, {3.449032272578125*^9, 
   3.449032406453125*^9}, {3.44903246440625*^9, 3.449032523265625*^9}, {
   3.4490326255625*^9, 3.4490327799375*^9}, {3.449032957046875*^9, 
   3.44903301346875*^9}, {3.44903305325*^9, 3.44903311321875*^9}, {
   3.449033151984375*^9, 3.449033193359375*^9}, {3.44903323034375*^9, 
   3.449033357703125*^9}, {3.44903339184375*^9, 3.449033406640625*^9}, {
   3.449033445265625*^9, 3.449033532453125*^9}, {3.449033572984375*^9, 
   3.44903360984375*^9}, {3.449033652625*^9, 3.44903370871875*^9}, {
   3.449033791546875*^9, 3.44903382540625*^9}, 3.4490339073125*^9, {
   3.449033953296875*^9, 3.4490340346875*^9}, {3.449034073265625*^9, 
   3.449034137109375*^9}, {3.449034187390625*^9, 3.4490343303125*^9}, {
   3.449034368796875*^9, 3.4490343926875*^9}, {3.4490344638125*^9, 
   3.449034706609375*^9}, {3.449034814140625*^9, 3.449034842765625*^9}, {
   3.4490349435625*^9, 3.44903497134375*^9}, {3.449035071484375*^9, 
   3.449035101375*^9}, {3.449035205078125*^9, 3.44903523146875*^9}, {
   3.449035323265625*^9, 3.449035351375*^9}, {3.44903543153125*^9, 
   3.449035483515625*^9}, {3.449035533703125*^9, 3.449035561875*^9}, {
   3.449035959203125*^9, 3.449035965890625*^9}, {3.449036230890625*^9, 
   3.449036439484375*^9}, {3.449036491984375*^9, 3.44903649709375*^9}, {
   3.449036545953125*^9, 3.449036552359375*^9}, {3.4490366296875*^9, 
   3.449036631953125*^9}, {3.449036728765625*^9, 3.449036729703125*^9}, {
   3.449036813375*^9, 3.4490368195625*^9}, {3.449036887203125*^9, 
   3.4490369071875*^9}, {3.44903695284375*^9, 3.449037002546875*^9}, {
   3.44903704946875*^9, 3.449037054828125*^9}, {3.44903710778125*^9, 
   3.449037160046875*^9}, {3.449037262703125*^9, 3.449037285*^9}, {
   3.44903735371875*^9, 3.449037358421875*^9}, {3.449037695875*^9, 
   3.449037712328125*^9}, {3.449037801046875*^9, 3.44903789815625*^9}, {
   3.449037983984375*^9, 3.44903798440625*^9}, {3.449038110484375*^9, 
   3.449038115296875*^9}, {3.44903817965625*^9, 3.4490381854375*^9}, {
   3.449038246265625*^9, 3.449038269171875*^9}, {3.4490384826875*^9, 
   3.449038483625*^9}, {3.449038521828125*^9, 3.449038586609375*^9}, 
   3.449038704921875*^9, {3.4490392099375*^9, 3.449039247421875*^9}, {
   3.449039323265625*^9, 3.449039327640625*^9}, {3.449039387984375*^9, 
   3.449039388796875*^9}, {3.44903962603125*^9, 3.44903964059375*^9}, {
   3.449039751125*^9, 3.44903977140625*^9}, {3.449039818453125*^9, 
   3.44903991909375*^9}, {3.449039958375*^9, 3.4490399593125*^9}, {
   3.449039990546875*^9, 3.449039992125*^9}, {3.449040059234375*^9, 
   3.44904008459375*^9}, {3.44904012121875*^9, 3.449040168703125*^9}, {
   3.449040231015625*^9, 3.449040242234375*^9}, {3.44904028540625*^9, 
   3.449040289890625*^9}, {3.4490405541875*^9, 3.449040636640625*^9}, {
   3.44904076871875*^9, 3.44904081878125*^9}, 3.44904085496875*^9, {
   3.449040931796875*^9, 3.449041185984375*^9}, {3.44904125821875*^9, 
   3.44904130353125*^9}, {3.449041337125*^9, 3.449041510671875*^9}, {
   3.44904158384375*^9, 3.4490416723125*^9}, {3.449041703375*^9, 
   3.44904171003125*^9}, {3.44904178484375*^9, 3.449041918125*^9}, {
   3.449042005203125*^9, 3.449042035484375*^9}, {3.449042182171875*^9, 
   3.449042232953125*^9}, {3.449042295953125*^9, 3.44904232021875*^9}, {
   3.4490427125625*^9, 3.4490427248125*^9}, {3.449042776421875*^9, 
   3.449042779609375*^9}, {3.449042811140625*^9, 3.449042933546875*^9}, {
   3.44904299596875*^9, 3.4490431539375*^9}, {3.449043420703125*^9, 
   3.449043561234375*^9}, {3.44904365525*^9, 3.44904365859375*^9}, {
   3.449043710375*^9, 3.449043797390625*^9}, {3.449043841015625*^9, 
   3.449043863515625*^9}, {3.449044106515625*^9, 3.4490441585625*^9}, {
   3.449044214203125*^9, 3.44904434534375*^9}, {3.4490443885*^9, 
   3.449044476296875*^9}, 3.44904451034375*^9, {3.44904457303125*^9, 
   3.449044583328125*^9}, {3.44904462403125*^9, 3.449044625453125*^9}, {
   3.449044656375*^9, 3.44904467403125*^9}, {3.449084573082141*^9, 
   3.449084574957153*^9}, {3.449085020553755*^9, 3.4490850418351407`*^9}, {
   3.4490851324138455`*^9, 3.449085184132927*^9}, {3.4490852185706472`*^9, 
   3.449085219383152*^9}, {3.4490852939617543`*^9, 3.4490853566184053`*^9}, {
   3.4490853876967297`*^9, 3.4490853943373966`*^9}, {3.4490854784004345`*^9, 
   3.4490855969636936`*^9}, {3.449406458118178*^9, 3.4494064780962887`*^9}},
 CellID->205192888]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 1, $CellContext`pt$$ = {1, 
    3}, $CellContext`\[Lambda]$$ = 0.2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`\[Lambda]$$], 0.2, 
       Style["\[Lambda]"]}, 0, 2, 0.1}, {{
       Hold[$CellContext`k$$], 1, 
       Style["k", Italic]}, 0.1, 3, 0.1}, {
      Hold[
       Row[{
         Manipulate`Place[1], 
         Manipulate`Place[2]}]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`pt$$], {1, 3}}, {-5, -5}, {5, 5}}}, 
    Typeset`size$$ = {540., {107.5, 112.5}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`\[Lambda]$10551$$ = 0, $CellContext`k$10552$$ = 
    0, $CellContext`pt$10553$$ = {0, 0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`k$$ = 
        1, $CellContext`pt$$ = {1, 3}, $CellContext`\[Lambda]$$ = 0.2}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Lambda]$$, $CellContext`\[Lambda]$10551$$, 0], 
        Hold[$CellContext`k$$, $CellContext`k$10552$$, 0], 
        Hold[$CellContext`pt$$, $CellContext`pt$10553$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`process[$CellContext`\[Lambda]$$, \
$CellContext`k$$, $CellContext`pt$$], 
      "Specifications" :> {{{$CellContext`\[Lambda]$$, 0.2, 
          Style["\[Lambda]"]}, 0, 2, 0.1, Appearance -> "Labeled", ImageSize -> 
         Normal, ControlPlacement -> 1}, {{$CellContext`k$$, 1, 
          Style["k", Italic]}, 0.1, 3, 0.1, Appearance -> "Labeled", 
         ImageSize -> Normal, ControlPlacement -> 2}, 
        Row[{
          Manipulate`Place[1], 
          Manipulate`Place[2]}], {{$CellContext`pt$$, {1, 3}}, {-5, -5}, {5, 
         5}, ControlType -> Locator}}, 
      "Options" :> {ControlPlacement -> {Top}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{591., {155., 160.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`process[
         Pattern[$CellContext`\[Lambda], 
          Blank[]], 
         Pattern[$CellContext`k, 
          Blank[]], 
         Pattern[$CellContext`pt, 
          Blank[]]] := 
       Module[{$CellContext`eq, $CellContext`x, $CellContext`t, \
$CellContext`tmax = 
          100, $CellContext`sol, $CellContext`paramPlot, \
$CellContext`solPlot, $CellContext`vData, $CellContext`x0, $CellContext`v0, \
$CellContext`lableSize = 
          14, $CellContext`initialConditionsString}, $CellContext`eq = 
          Derivative[
             2][$CellContext`x][$CellContext`t] - $CellContext`\[Lambda] (
             1 - $CellContext`x[$CellContext`t]^2) 
            Derivative[
             1][$CellContext`x][$CellContext`t] + $CellContext`k \
$CellContext`x[$CellContext`t] == 0; $CellContext`sol = First[
            
            NDSolve[{$CellContext`eq, $CellContext`x[0] == 
              Part[$CellContext`pt, 1], Derivative[1][$CellContext`x][0] == 
              Part[$CellContext`pt, 2]}, $CellContext`x, {$CellContext`t, 
              0, $CellContext`tmax}]]; $CellContext`initialConditionsString = 
          Style[
            Row[{
              Style["x", Italic], "(0) = ", 
              NumberForm[
               Part[$CellContext`pt, 1], {3, 2}, NumberSigns -> {"-", "+"}], 
              "   ", 
              Derivative[1][
               Style["x", Italic]], "(0) = ", 
              NumberForm[
               Part[$CellContext`pt, 2], {3, 2}, 
               NumberSigns -> {"-", "+"}]}], $CellContext`lableSize, 
            TextAlignment -> Center]; $CellContext`paramPlot = 
          ParametricPlot[
            Evaluate[
             ReplaceAll[{
               $CellContext`x[$CellContext`t], 
               Derivative[
               1][$CellContext`x][$CellContext`t]}, $CellContext`sol]], \
{$CellContext`t, 0, $CellContext`tmax}, AspectRatio -> Automatic, 
            PlotRange -> {{-5, 5}, {-5, 5}}, PlotPoints -> 100, Frame -> True,
             FrameLabel -> {{
               Style[
                Row[{
                  Derivative[1][
                   Style["x", Italic]], "(", 
                  Style["t", Italic], ")"}], $CellContext`lableSize], None}, {
              
               Style[
                Row[{
                  Style["x", Italic], "(", 
                  Style["t", Italic], ")"}], $CellContext`lableSize], 
               Column[{
                 Style[
                 "phase plane plot", $CellContext`lableSize], \
$CellContext`initialConditionsString}, Alignment -> Center]}}, 
            ImageSize -> {270, 220}, ImagePadding -> 40, PlotStyle -> 
            Red]; $CellContext`solPlot = Plot[
            Evaluate[
             ReplaceAll[
              $CellContext`x[$CellContext`t], $CellContext`sol]], \
{$CellContext`t, 0, $CellContext`tmax}, PlotRange -> All, FrameLabel -> {{
               Style[
                Row[{
                  Style["x", Italic], "(", 
                  Style["t", Italic], ")"}], $CellContext`lableSize], None}, {
              
               Style["time", $CellContext`lableSize], 
               Style[
                Row[{
                  Style["x", Italic], "(", 
                  Style["t", Italic], 
                  ") versus time"}], $CellContext`lableSize]}}, AspectRatio -> 
            1, Frame -> True, ImageSize -> {270, 220}, ImagePadding -> 40, 
            PlotStyle -> Red]; 
         Grid[{{$CellContext`paramPlot, $CellContext`solPlot}}, Frame -> None,
            Spacings -> 0]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->357601772],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Phase Plane Plot of the Van der Pol Differential Equation",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
PhasePlanePlotOfTheVanDerPolDifferentialEquation/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
PhasePlanePlotOfTheVanDerPolDifferentialEquation/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
PhasePlanePlotOfTheVanDerPolDifferentialEquation/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
PhasePlanePlotOfTheVanDerPolDifferentialEquation/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
PhasePlanePlotOfTheVanDerPolDifferentialEquation/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Nasser Abbasi",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Nasser+Abbasi"],
     None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Nasser+Abbasi"]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6],
 CellID->95413255],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
PhasePlanePlotOfTheVanDerPolDifferentialEquation"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{771, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Phase Plane Plot of the Van der Pol Differential Equation - \
Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[647, 23, 249, 4, 70, "Section"],
Cell[899, 29, 20518, 404, 70, "Input",
 CellID->205192888]
}, Open  ]],
Cell[21432, 436, 6303, 137, 70, "Output",
 CellID->357601772],
Cell[CellGroupData[{
Cell[27760, 577, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[28136, 588, 1092, 31, 70, "Text"],
Cell[29231, 621, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[29571, 632, 455, 15, 70, "Text",
 CellID->95413255],
Cell[CellGroupData[{
Cell[30051, 651, 847, 24, 70, "Text"],
Cell[30901, 677, 1224, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature xTNtyKOgniKe5BDmd7Sk7xnD *)
