(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     26155,        638]
NotebookOptionsPosition[     24968,        595]
NotebookOutlinePosition[     25613,        619]
CellTagsIndexPosition[     25570,        616]
WindowTitle->Brownian Motion in 2D and the Fokker-Planck Equation - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Brownian Motion in 2D and the Fokker-Planck Equation", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"steps", "=", "1000"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"L", "=", "5.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"normaldx", "[", "nsteps_", "]"}], ":=", 
  RowBox[{"Partition", "[", 
   RowBox[{
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", "1"}], "]"}], ",", 
      RowBox[{"2", "*", "nsteps"}]}], "]"}], " ", ",", "2"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"dx", "[", 
   RowBox[{"mu_", ",", "diff_", ",", "nsteps_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"mu", "/", "nsteps"}], "+", 
       RowBox[{
        RowBox[{"diff", ".", "#"}], "/", 
        RowBox[{"Sqrt", "[", "nsteps", "]"}]}]}], ")"}], "&"}], "/@", 
    RowBox[{"normaldx", "[", "nsteps", "]"}]}], ")"}]}], "\n", 
 RowBox[{
  RowBox[{"walk", "[", "p___", "]"}], ":=", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"dx", "[", "p", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"walks", "[", 
   RowBox[{"m_", ",", "p___"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"walk", "[", "p", "]"}], ",", 
    RowBox[{"{", "m", "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"cuadform", "[", 
    RowBox[{"m_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"v", ".", "m", ".", "v"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.445105207778185*^9, 3.445105237239482*^9}, 
   3.4451135927639008`*^9, 3.445113649080216*^9, 3.445113717786316*^9, 
   3.4451139580867777`*^9, {3.44515255464329*^9, 3.445152554812199*^9}, {
   3.445323574934183*^9, 3.445323579346096*^9}},
 CellID->61595442],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DynamicModule", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sigma", ",", " ", "w", ",", " ", "dmat", ",", " ", "A"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sigma", "=", 
       RowBox[{"DiagonalMatrix", "[", "eigend", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"w", "=", 
       RowBox[{"walks", "[", 
        RowBox[{"nparticles", ",", "drift", ",", "sigma", ",", "steps"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"dmat", "=", 
       RowBox[{
        RowBox[{"sigma", "^", "2"}], " ", "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"A", "=", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", "Pi", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Det", "[", "dmat", "]"}], "]"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Dynamic", "[", 
       RowBox[{"ContourPlot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "/", "time"}], " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"cuadform", "[", 
              RowBox[{
               RowBox[{"Inverse", "[", "dmat", "]"}], " ", ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"x", ",", " ", "y"}], "}"}], "-", 
                RowBox[{"drift", " ", "*", " ", "time"}]}]}], "]"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"4", " ", "time"}], ")"}]}], "]"}]}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", 
           RowBox[{
            RowBox[{"-", "L"}], "/", "2"}], ",", " ", 
           RowBox[{"L", "/", "2"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"y", ",", " ", 
           RowBox[{
            RowBox[{"-", "L"}], "/", "2"}], ",", " ", 
           RowBox[{"L", "/", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
         
         RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"ControlActive", "[", 
           RowBox[{"15", ",", " ", "50"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ColorFunction", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{".7", ",", " ", 
              RowBox[{"1.0", "-", " ", "#"}], ",", " ", 
              RowBox[{"1.0", "-", "#"}]}], "]"}], "&"}], ")"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Epilog", "\[Rule]", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Black", ",", " ", 
            RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"Dynamic", "[", 
              RowBox[{"w", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", 
                RowBox[{
                 RowBox[{"Round", "[", 
                  RowBox[{"time", " ", "*", " ", "steps"}], "]"}], " ", "+", 
                 " ", "1"}], ",", " ", "All"}], "\[RightDoubleBracket]"}], 
              "]"}], "]"}]}], "}"}]}]}], "]"}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nparticles", ",", " ", "10", ",", " ", "\"\<particles\>\""}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"10", ",", " ", "50", ",", " ", "100", ",", " ", "500"}], 
      "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"time", ",", " ", 
       RowBox[{"N", "[", 
        RowBox[{"20", "/", "steps"}], "]"}], ",", " ", "\"\<time\>\""}], 
      "}"}], ",", " ", 
     RowBox[{"N", "[", 
      RowBox[{"1", "/", "steps"}], "]"}], ",", " ", ".99", ",", " ", 
     RowBox[{"N", "[", 
      RowBox[{"1", "/", "steps"}], "]"}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drift", ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.0", ",", " ", "0.0"}], "}"}], ",", "\"\<drift\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "L"}], "/", "2"}], ",", " ", 
       RowBox[{
        RowBox[{"-", "L"}], "/", "2"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"L", "/", "2"}], ",", " ", 
       RowBox[{"L", "/", "2"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"L", "/", "20"}], ",", " ", 
       RowBox[{"L", "/", "20"}]}], "}"}], ",", " ", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eigend", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"L", "/", "20"}], ",", " ", 
         RowBox[{"L", "/", "20"}]}], "}"}], ",", "\"\<diffussion\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01", ",", " ", "0.01"}], "}"}], ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"L", "/", "5"}], ",", " ", 
       RowBox[{"L", "/", "5"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"L", "/", "100"}], ",", " ", 
       RowBox[{"L", "/", "100"}]}], "}"}], ",", " ", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SynchronousUpdating", "\[Rule]", "False"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.445105459274975*^9, 3.445105493911274*^9}, {
   3.445105606717538*^9, 3.445105667236269*^9}, {3.4451062770161858`*^9, 
   3.445106398646809*^9}, {3.445106463885816*^9, 3.4451064674748383`*^9}, {
   3.445106497818614*^9, 3.445106513620779*^9}, {3.445106581021655*^9, 
   3.445106622770495*^9}, {3.445106660302421*^9, 3.445106664173386*^9}, {
   3.445106696575494*^9, 3.4451067048912363`*^9}, {3.4451068097413282`*^9, 
   3.445106809831349*^9}, {3.445106863841675*^9, 3.4451068869359903`*^9}, {
   3.445106927463603*^9, 3.445106936510455*^9}, {3.4451070333322563`*^9, 
   3.445107034670907*^9}, {3.445107183951293*^9, 3.445107185814183*^9}, {
   3.445107244494858*^9, 3.445107452559916*^9}, {3.445107488410955*^9, 
   3.4451075340647373`*^9}, {3.445107570289391*^9, 3.445107582642877*^9}, {
   3.4451076534911003`*^9, 3.445107666203712*^9}, {3.445107705647303*^9, 
   3.445107799635419*^9}, {3.445107911809203*^9, 3.445107912174911*^9}, {
   3.4451079902361717`*^9, 3.4451080181856956`*^9}, {3.445108065066279*^9, 
   3.445108281029128*^9}, {3.445108367373929*^9, 3.445108376124958*^9}, {
   3.445108409448741*^9, 3.445108513999793*^9}, {3.445110090980568*^9, 
   3.445110203950986*^9}, {3.4451102550130243`*^9, 3.445110275812352*^9}, {
   3.445110450368021*^9, 3.4451104627932663`*^9}, {3.445110600771862*^9, 
   3.445110623934018*^9}, {3.445110662737197*^9, 3.445110685255875*^9}, {
   3.44511344109923*^9, 3.445113441177527*^9}, {3.44511347938223*^9, 
   3.4451134999231663`*^9}, {3.445113732293833*^9, 3.445113737619012*^9}, {
   3.44511379973608*^9, 3.445113831635685*^9}, {3.445113878413725*^9, 
   3.445113880674039*^9}, {3.4451142623725863`*^9, 3.4451142901323833`*^9}, 
   3.445114560032102*^9, {3.445114629954274*^9, 3.445114667280373*^9}, {
   3.4451148599439173`*^9, 3.4451148626569357`*^9}, {3.445152086390842*^9, 
   3.445152193774544*^9}, {3.445152271159828*^9, 3.445152353910952*^9}, {
   3.445152431668721*^9, 3.445152453629315*^9}, {3.445152735277247*^9, 
   3.445152781704002*^9}, {3.445152818824686*^9, 3.445152874315249*^9}, {
   3.445152956107334*^9, 3.445152996857211*^9}, {3.445153041007516*^9, 
   3.445153054175242*^9}, {3.445154198459896*^9, 3.445154209580579*^9}, {
   3.4451542505631113`*^9, 3.445154281834553*^9}, {3.445154361513612*^9, 
   3.4451543640881157`*^9}, {3.44515460722402*^9, 3.44515464532909*^9}, {
   3.4451549599628487`*^9, 3.445155058516431*^9}, {3.445155094191408*^9, 
   3.44515510847449*^9}, {3.445155660743948*^9, 3.445155696420826*^9}, {
   3.445155731876486*^9, 3.4451557378730593`*^9}, {3.4451558538782797`*^9, 
   3.4451558574490232`*^9}, {3.445156123939623*^9, 3.445156183792056*^9}, {
   3.445156276519026*^9, 3.445156329416888*^9}, {3.445156364517321*^9, 
   3.445156370587982*^9}, {3.4451586355616903`*^9, 3.4451588036247263`*^9}, {
   3.445158884625394*^9, 3.445158893153347*^9}, {3.445158980579391*^9, 
   3.4451589858990517`*^9}, {3.445159041629849*^9, 3.445159043611328*^9}, {
   3.445159078982071*^9, 3.445159080023591*^9}, {3.445159148197611*^9, 
   3.4451591922669077`*^9}, {3.4451592246678*^9, 3.44515922578786*^9}, {
   3.445159298385603*^9, 3.44515929962479*^9}, {3.445159341790296*^9, 
   3.44515934259265*^9}, 3.44515939771093*^9, {3.445159582473364*^9, 
   3.4451595849891367`*^9}, {3.445159620327839*^9, 3.4451596415034*^9}, {
   3.445159703428686*^9, 3.445159717143931*^9}, {3.445159958895281*^9, 
   3.445160032833741*^9}, {3.44516017363358*^9, 3.44516017648318*^9}, {
   3.445163951918263*^9, 3.4451639545474377`*^9}, {3.445164180194006*^9, 
   3.445164227228517*^9}, {3.445164361210935*^9, 3.445164438568363*^9}, {
   3.445164481703911*^9, 3.445164482483139*^9}, {3.445164625449524*^9, 
   3.445164637385627*^9}, {3.4451655569916153`*^9, 3.4451655826873293`*^9}, {
   3.4451656912786503`*^9, 3.4451656964177732`*^9}, {3.445165755643894*^9, 
   3.445165787627386*^9}, {3.4451658508328657`*^9, 3.445165850913775*^9}, {
   3.445165894721169*^9, 3.445165896163129*^9}, {3.445165981888843*^9, 
   3.4451660475528603`*^9}, {3.4451660916956053`*^9, 3.445166116908897*^9}, {
   3.445166179153954*^9, 3.445166185524845*^9}, {3.445166392921708*^9, 
   3.4451663938674717`*^9}, {3.445170762080048*^9, 3.445170806354645*^9}, {
   3.44517097888623*^9, 3.44517099022996*^9}, {3.445171323125703*^9, 
   3.4451713892301064`*^9}, {3.445171479697927*^9, 3.445171488631679*^9}, {
   3.445171648469748*^9, 3.445171649374662*^9}, {3.445173996574057*^9, 
   3.445174011285161*^9}, 3.445174050825472*^9, {3.445196527167165*^9, 
   3.445196528861289*^9}, {3.44523872518791*^9, 3.445238741713776*^9}, {
   3.4452391224552393`*^9, 3.445239138548482*^9}, 3.44523924091103*^9, {
   3.445245408620008*^9, 3.445245418934196*^9}, {3.445246183022807*^9, 
   3.445246205171165*^9}, {3.445336473385255*^9, 3.445336484516754*^9}, {
   3.446043129674405*^9, 3.44604313625253*^9}, {3.446043320065*^9, 
   3.446043320799375*^9}, {3.446043386080625*^9, 3.446043443861875*^9}, 
   3.44628949982059*^9, {3.4462895517031994`*^9, 3.446289557478777*^9}, {
   3.44629381514087*^9, 3.446293815586914*^9}},
 CellID->1282225596]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`drift$$ = {0., 
    0.}, $CellContext`eigend$$ = {0.25, 0.25}, $CellContext`nparticles$$ = 
    10, $CellContext`time$$ = 0.02, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`nparticles$$], 10, "particles"}, {10, 50, 100, 
      500}}, {{
       Hold[$CellContext`time$$], 0.02, "time"}, 0.001, 0.99, 0.001}, {{
       Hold[$CellContext`drift$$], {0., 0.}, "drift"}, {-2.5, -2.5}, {2.5, 
      2.5}, {0.25, 0.25}}, {{
       Hold[$CellContext`eigend$$], {0.25, 0.25}, "diffussion"}, {0.01, 
      0.01}, {1., 1.}, {0.05, 0.05}}}, Typeset`size$$ = {360., {178., 182.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`nparticles$16279$$ = 0, $CellContext`time$16280$$ = 
    0, $CellContext`drift$16281$$ = {0, 0}, $CellContext`eigend$16282$$ = {0, 
    0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`drift$$ = {0., 
         0.}, $CellContext`eigend$$ = {0.25, 0.25}, $CellContext`nparticles$$ = 
        10, $CellContext`time$$ = 0.02}, "ControllerVariables" :> {
        Hold[$CellContext`nparticles$$, $CellContext`nparticles$16279$$, 0], 
        Hold[$CellContext`time$$, $CellContext`time$16280$$, 0], 
        Hold[$CellContext`drift$$, $CellContext`drift$16281$$, {0, 0}], 
        Hold[$CellContext`eigend$$, $CellContext`eigend$16282$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      DynamicModule[{$CellContext`sigma, $CellContext`w, $CellContext`dmat, \
$CellContext`A}, $CellContext`sigma = 
         DiagonalMatrix[$CellContext`eigend$$]; $CellContext`w = \
$CellContext`walks[$CellContext`nparticles$$, $CellContext`drift$$, \
$CellContext`sigma, $CellContext`steps]; $CellContext`dmat = \
$CellContext`sigma^2/2; $CellContext`A = 1/(4 Pi Sqrt[
            Det[$CellContext`dmat]]); Dynamic[
          
          ContourPlot[($CellContext`A/$CellContext`time$$) 
           Exp[(-$CellContext`cuadform[
                
                Inverse[$CellContext`dmat], {
                 DemonstrationsTools`x, $CellContext`y} - \
$CellContext`drift$$ $CellContext`time$$])/(4 $CellContext`time$$)], {
           DemonstrationsTools`x, (-$CellContext`L)/2, $CellContext`L/
            2}, {$CellContext`y, (-$CellContext`L)/2, $CellContext`L/2}, 
           AspectRatio -> 1, PlotRange -> All, Frame -> True, PlotPoints -> 
           ControlActive[15, 50], 
           ColorFunction -> (RGBColor[0.7, 1. - #, 1. - #]& ), 
           ColorFunctionScaling -> True, Epilog -> {Black, 
             PointSize[Medium], 
             Point[
              Dynamic[
               
               Part[$CellContext`w, All, 
                Round[$CellContext`time$$ $CellContext`steps] + 1, All]]]}]]],
       "Specifications" :> {{{$CellContext`nparticles$$, 10, "particles"}, {
         10, 50, 100, 500}}, {{$CellContext`time$$, 0.02, "time"}, 0.001, 
         0.99, 0.001}, {{$CellContext`drift$$, {0., 0.}, 
          "drift"}, {-2.5, -2.5}, {2.5, 2.5}, {0.25, 0.25}, ControlPlacement -> 
         Left}, {{$CellContext`eigend$$, {0.25, 0.25}, "diffussion"}, {0.01, 
         0.01}, {1., 1.}, {0.05, 0.05}, ControlPlacement -> Left}}, 
      "Options" :> {SynchronousUpdating -> False}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{537., {235., 240.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(({$CellContext`walks[
          Pattern[$CellContext`m, 
           Blank[]], 
          Pattern[$CellContext`p, 
           BlankNullSequence[]]] := Table[
          $CellContext`walk[$CellContext`p], {$CellContext`m}], \
$CellContext`walk[
          Pattern[$CellContext`p, 
           BlankNullSequence[]]] := Accumulate[
          $CellContext`dx[$CellContext`p]], $CellContext`dx[
          Pattern[$CellContext`mu, 
           Blank[]], 
          Pattern[$CellContext`diff, 
           Blank[]], 
          Pattern[$CellContext`nsteps, 
           Blank[]]] := 
        Map[$CellContext`mu/$CellContext`nsteps + 
          Dot[$CellContext`diff, #]/Sqrt[$CellContext`nsteps]& , 
          $CellContext`normaldx[$CellContext`nsteps]], $CellContext`normaldx[
          Pattern[$CellContext`nsteps, 
           Blank[]]] := Partition[
          RandomReal[
           NormalDistribution[0, 1], 2 $CellContext`nsteps], 
          2], $CellContext`steps = 1000, $CellContext`cuadform[
          Pattern[$CellContext`m, 
           Blank[]], 
          Pattern[$CellContext`v, 
           Blank[]]] := 
        Dot[$CellContext`v, $CellContext`m, $CellContext`v], $CellContext`L = 
        5., Attributes[PlotRange] = {ReadProtected}}; 
      Typeset`initDone$$ = True); ReleaseHold[{{
         HoldComplete[$CellContext`steps = 1000; Null], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`L = 5.; Null], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`normaldx[
            Pattern[$CellContext`nsteps, 
             Blank[]]] := Partition[
            RandomReal[
             NormalDistribution[0, 1], 2 $CellContext`nsteps], 2]], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`dx[
            Pattern[$CellContext`mu, 
             Blank[]], 
            Pattern[$CellContext`diff, 
             Blank[]], 
            Pattern[$CellContext`nsteps, 
             Blank[]]] := 
          Map[$CellContext`mu/$CellContext`nsteps + 
            Dot[$CellContext`diff, #]/Sqrt[$CellContext`nsteps]& , 
            $CellContext`normaldx[$CellContext`nsteps]]], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`walk[
            Pattern[$CellContext`p, 
             BlankNullSequence[]]] := Accumulate[
            $CellContext`dx[$CellContext`p]]], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`walks[
            Pattern[$CellContext`m, 
             Blank[]], 
            Pattern[$CellContext`p, 
             BlankNullSequence[]]] := Table[
            $CellContext`walk[$CellContext`p], {$CellContext`m}]], 
         HoldComplete[Null], 
         HoldComplete[$CellContext`cuadform[
             Pattern[$CellContext`m, 
              Blank[]], 
             Pattern[$CellContext`v, 
              Blank[]]] := 
           Dot[$CellContext`v, $CellContext`m, $CellContext`v]; Null]}}]; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->234231291],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Brownian Motion in 2D and the Fokker-Planck Equation",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
BrownianMotionIn2DAndTheFokkerPlanckEquation/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
BrownianMotionIn2DAndTheFokkerPlanckEquation/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
BrownianMotionIn2DAndTheFokkerPlanckEquation/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
BrownianMotionIn2DAndTheFokkerPlanckEquation/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
BrownianMotionIn2DAndTheFokkerPlanckEquation/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Alejandro Luque Estepa",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Alejandro+Luque+\
Estepa"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Alejandro+Luque+\
Estepa"]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
BrownianMotionIn2DAndTheFokkerPlanckEquation"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{710, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Brownian Motion in 2D and the Fokker-Planck Equation - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[642, 23, 244, 4, 70, "Section"],
Cell[889, 29, 1667, 48, 70, "Input",
 InitializationCell->True,
 CellID->61595442],
Cell[2559, 79, 10916, 223, 70, "Input",
 CellID->1282225596]
}, Open  ]],
Cell[13490, 305, 7082, 149, 70, "Output",
 CellID->234231291],
Cell[CellGroupData[{
Cell[20597, 458, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[20973, 469, 1067, 31, 70, "Text"],
Cell[22043, 502, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[22383, 513, 462, 15, 70, "Text"],
Cell[CellGroupData[{
Cell[22870, 532, 847, 24, 70, "Text"],
Cell[23720, 558, 1220, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature RSzE6jDug#OyBDTyShZVORHV *)
