(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     38865,        805]
NotebookOptionsPosition[     38413,        784]
NotebookOutlinePosition[     38784,        800]
CellTagsIndexPosition[     38741,        797]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["A 1D ODE explorer", "Subtitle",
 CellChangeTimes->{{3.455989496703125*^9, 3.455989504703125*^9}, 
   3.4559918699375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Quiet", "[", "\[IndentingNewLine]", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "eqn", ",", "u", ",", "t", ",", "equilib", ",", "sol", ",", "t0", ",", 
        "x0", ",", "x", ",", "k", ",", "a", ",", "b"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"eqn", ":=", 
        RowBox[{"ode", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "\[Rule]", "u"}], ",", 
           RowBox[{"k", "\[Rule]", "kk"}], ",", 
           RowBox[{"a", "\[Rule]", "aa"}], ",", 
           RowBox[{"b", "\[Rule]", "bb"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"equilib", ":=", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"eqn", "\[Equal]", "0"}], ",", "u"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", 
        RowBox[{"x0", ",", "t0"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sol", "[", 
         RowBox[{"{", 
          RowBox[{"t0_", ",", "x0_"}], "}"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"DSolve", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"u", "'"}], "[", "t", "]"}], "\[Equal]", 
              RowBox[{"(", 
               RowBox[{"eqn", "/.", 
                RowBox[{"u", ":>", 
                 RowBox[{"u", "[", "t", "]"}]}]}], ")"}]}], ",", 
             RowBox[{
              RowBox[{"u", "[", "t0", "]"}], "\[Equal]", "x0"}]}], "}"}], ",", 
           RowBox[{"u", "[", "t", "]"}], ",", "t"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Pane", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Grid", "[", 
          RowBox[{"{", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Show", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Graphics", "[", 
                RowBox[{"Thickness", "[", "0.01", "]"}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Plot", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{"u", "/.", "equilib"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0.", ",", "T"}], "}"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"xmin", ",", "xmax"}], "}"}]}]}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Map", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Plot", "[", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"u", "[", "t", "]"}], "/.", 
                    RowBox[{"sol", "[", "#", "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "T"}], "}"}], ",", 
                    RowBox[{"ColorFunction", "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Hue", "[", "#2", "]"}], "&"}], ")"}]}], ",", 
                    RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"xmin", ",", "xmax"}], "}"}]}]}], "]"}], "&"}], 
                 ",", "IC"}], "]"}], "\[IndentingNewLine]", ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Graphics", "[", 
                RowBox[{"Directive", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
                   RowBox[{"Hue", "[", 
                    RowBox[{"0.7", ",", "0.2", ",", "0.7", ",", "0.4"}], 
                    "]"}]}], "}"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
               RowBox[{"VectorPlot", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Evaluate", "[", "eqn", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"u", ",", "xmin", ",", "xmax"}], "}"}], ",", 
                 RowBox[{"Axes", "\[Rule]", "True"}], ",", 
                 RowBox[{"AxesLabel", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<t\>\"", ",", "\"\<x\>\""}], "}"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"VectorPoints", "\[Rule]", "15"}], ",", 
                 RowBox[{"VectorScale", "\[Rule]", "Medium"}]}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Axes", "\[Rule]", "True"}], ",", 
               RowBox[{"AxesLabel", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"\"\<t\>\"", ",", "\"\<x\>\""}], "}"}]}], ",", 
               RowBox[{"ImageSize", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"300", ",", "300"}], "}"}]}], ",", 
               RowBox[{"PlotRange", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"xmin", ",", "xmax"}], "}"}]}], ",", 
               RowBox[{"AspectRatio", "\[Rule]", 
                RowBox[{"1", "/", "GoldenRatio"}]}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Spacer", "[", "10", "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Column", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Text", "@", 
                 RowBox[{"Column", "[", "\[IndentingNewLine]", 
                  RowBox[{"Prepend", "[", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Which", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "IC", "]"}], ">", "0"}], ",", 
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{"u", "[", "t", "]"}], "/.", 
                    RowBox[{"Map", "[", 
                    RowBox[{"sol", ",", "IC"}], "]"}]}], "]"}], ",", "True", 
                    ",", 
                    RowBox[{
                    RowBox[{"u", "[", "t", "]"}], "/.", 
                    RowBox[{"DSolve", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"u", "'"}], "[", "t", "]"}], "\[Equal]", 
                    RowBox[{"(", 
                    RowBox[{"eqn", "/.", 
                    RowBox[{"u", ":>", 
                    RowBox[{"u", "[", "t", "]"}]}]}], ")"}]}], ",", 
                    RowBox[{
                    RowBox[{"u", "[", "t0", "]"}], "\[Equal]", "x0"}]}], 
                    "}"}], ",", 
                    RowBox[{"u", "[", "t", "]"}], ",", "t"}], "]"}]}]}], 
                    "]"}], "\[IndentingNewLine]", ",", 
                    "\"\<solutions: \\n\>\""}], "]"}], "]"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Spacer", "[", "10", "]"}], ",", 
                RowBox[{"Text", "@", 
                 RowBox[{"Column", "[", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"{", 
                    RowBox[{"\"\<Equilibria: \\n\>\"", ",", "equilib"}], 
                    "}"}], "]"}], "]"}]}]}], "}"}], "]"}]}], "}"}], "}"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"500", ",", "300"}], "}"}], ",", 
         RowBox[{"Alignment", "\[Rule]", "Center"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}], 
   "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ode", ",", 
       RowBox[{
        RowBox[{"-", " ", "k"}], " ", "x", 
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}]}], ",", "\"\<x'==\>\""}], "}"}], ",", 
     "InputField"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<parameters\>\"", ",", "Bold"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"kk", ",", "2", ",", "\"\<k\>\""}], "}"}], ",", "0", ",", "3", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "\[IndentingNewLine]",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aa", ",", "0.5", ",", "\"\<a\>\""}], "}"}], ",", "0", ",", "3",
      ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"bb", ",", "0", ",", "\"\<b\>\""}], "}"}], ",", "0", ",", "3", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], "\[IndentingNewLine]",
    ",", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", "10."}], "}"}], ",", "1", ",", "30.", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", "\n", "\t", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "xmin", ",", "0", ",", "\"\<\!\(\*SubscriptBox[\(x\), \(min\)]\)\>\""}],
       "}"}], ",", 
     RowBox[{"-", "10"}], ",", "10.", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", "\n", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "xmax", ",", "1", ",", "\"\<\!\(\*SubscriptBox[\(x\), \(max\)]\)\>\""}],
       "}"}], ",", 
     RowBox[{"xmin", "+", "1"}], ",", "10.", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<initial conditions:\>\"", ",", "Bold"}], "]"}], ",", 
   RowBox[{"Style", "[", "\"\<      Alt-Click to create locators\>\"", "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"IC", ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "Locator", ",", 
     RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], "}"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", ",", "9"}], 
     "}"}]}], ",", 
   RowBox[{"Deployed", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", "\[IndentingNewLine]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ODESolve0", "[", 
        RowBox[{
        "xdot_List", ",", "xvar_List", ",", "icond_List", ",", "\n", "\t\t", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "t0_", ",", "T_"}], "}"}], ",", "opt___"}], 
        "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Return", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"xvar", " ", "/.", " ", 
               RowBox[{"Map", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "\[Rule]", 
                   RowBox[{"#", "[", "t", "]"}]}], "&"}], ",", "#"}], "]"}]}],
               "&"}], " ", "[", "xvar", "]"}], ")"}], " ", "/.", 
           RowBox[{"First", "[", 
            RowBox[{"NDSolve", "[", "\n", "\t", 
             RowBox[{
              RowBox[{"Join", "[", "\n", "\t", 
               RowBox[{
                RowBox[{"Table", "[", "\n", "\t ", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"xvar", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "'"}], "[", "t", "]"}], "==",
                    "\n", "         ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"xdot", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "/.", " ", 
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "\[Rule]", 
                    RowBox[{"#", "[", "t", "]"}]}], "&"}], ",", "#"}], 
                    "]"}]}], "&"}], " ", "[", "xvar", "]"}], ")"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"Length", "[", "xvar", "]"}]}], "}"}]}], "]"}], 
                ",", "\n", "\t ", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"xvar", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", "t0", "]"}], "==", 
                   RowBox[{"icond", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"Length", "[", "xvar", "]"}]}], "}"}]}], "]"}]}], 
               "]"}], ",", "xvar", ",", "\n", "\t", 
              RowBox[{"{", 
               RowBox[{"t", ",", "t0", ",", "T"}], "}"}], ",", "opt"}], "]"}],
             "\n", "    ", "]"}]}], "\n", "]"}]}], "]"}]}], ";", "\n", "\n", 
      RowBox[{"(*", "\n", 
       RowBox[{"Solve", " ", "with", " ", "a", " ", "table", " ", "of", " ", 
        RowBox[{"init", ".", " ", "conditions"}], " ", 
        RowBox[{"(", 
         RowBox[{"table", " ", "of", " ", 
          RowBox[{"Interpol", ".", "Funct", ".", " ", "object"}]}], ")"}]}], 
       "\n", "*)"}], "\n", "\n", 
      RowBox[{
       RowBox[{"ODESolve", "[", 
        RowBox[{"xdot_List", ",", "xvar_List", ",", "ictab_List", ",", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "t0_", ",", "T_"}], "}"}], ",", "opt___"}], 
        "]"}], ":=", "\n", "\t", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ODESolve0", "[", 
            RowBox[{"xdot", ",", "xvar", ",", "#", ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "t0", ",", "T"}], "}"}], ",", "opt"}], "]"}], 
           ")"}], "&"}], ",", "ictab"}], "]"}]}], ";"}], "\n", "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.418362395515625*^9, 3.41836265725*^9}, {
   3.41836271859375*^9, 3.418362728234375*^9}, {3.41836275934375*^9, 
   3.418362851015625*^9}, {3.418362900328125*^9, 3.418362921625*^9}, {
   3.418362958765625*^9, 3.4183630113125*^9}, {3.418364006203125*^9, 
   3.418364061015625*^9}, {3.418364095484375*^9, 3.418364110390625*^9}, {
   3.41836414846875*^9, 3.41836415196875*^9}, {3.418364257796875*^9, 
   3.41836430628125*^9}, {3.41836435121875*^9, 3.4183643813125*^9}, {
   3.418364682296875*^9, 3.418364747796875*^9}, 3.41836479725*^9, {
   3.418364942515625*^9, 3.41836494378125*^9}, {3.418365053953125*^9, 
   3.418365111046875*^9}, {3.41836514565625*^9, 3.418365146984375*^9}, {
   3.418365198125*^9, 3.41836522290625*^9}, {3.418392141625*^9, 
   3.418392156828125*^9}, {3.418392189453125*^9, 3.418392218078125*^9}, {
   3.4183970125*^9, 3.41839701975*^9}, {3.4185445906875*^9, 
   3.418544600203125*^9}, {3.418544660359375*^9, 3.4185447579375*^9}, {
   3.4192431083125*^9, 3.419243119484375*^9}, {3.419243151046875*^9, 
   3.4192431590625*^9}, {3.420475859640625*^9, 3.420475865546875*^9}, {
   3.436099099578125*^9, 3.43609917496875*^9}, {3.436099288875*^9, 
   3.43609930825*^9}, {3.4360994246875*^9, 3.43609943925*^9}, {
   3.43609978409375*^9, 3.4360998369375*^9}, {3.43609989740625*^9, 
   3.43609995521875*^9}, {3.436099997828125*^9, 3.436099998390625*^9}, {
   3.436100100265625*^9, 3.436100151484375*^9}, {3.436100914453125*^9, 
   3.436100915484375*^9}, {3.43610097103125*^9, 3.436100978046875*^9}, {
   3.436104893421875*^9, 3.436104920390625*^9}, {3.436104956015625*^9, 
   3.436104958453125*^9}, {3.4361050116875*^9, 3.436105130984375*^9}, {
   3.436105215109375*^9, 3.436105223359375*^9}, {3.43610530959375*^9, 
   3.4361053116875*^9}, 3.436105439953125*^9, {3.436105596859375*^9, 
   3.4361056043125*^9}, {3.43610564578125*^9, 3.436105848109375*^9}, {
   3.436105878265625*^9, 3.436105909546875*^9}, 3.4361059835625*^9, {
   3.436106092796875*^9, 3.43610609540625*^9}, {3.436106222921875*^9, 
   3.43610629421875*^9}, {3.436106358734375*^9, 3.436106359453125*^9}, {
   3.436106736328125*^9, 3.436106738265625*^9}, {3.43610695284375*^9, 
   3.436106998375*^9}, {3.4361071105*^9, 3.43610712059375*^9}, 
   3.436150668296875*^9, {3.43615100478125*^9, 3.436151017*^9}, {
   3.4361510990625*^9, 3.436151144328125*^9}, {3.436151276015625*^9, 
   3.43615127871875*^9}, {3.436153122390625*^9, 3.43615313378125*^9}, {
   3.43615316778125*^9, 3.43615323403125*^9}, {3.436153318109375*^9, 
   3.4361533424375*^9}, {3.4361533995*^9, 3.4361534144375*^9}, {
   3.43615350259375*^9, 3.436153505390625*^9}, {3.436153555078125*^9, 
   3.4361535829375*^9}, {3.43615362315625*^9, 3.4361536341875*^9}, {
   3.436153813421875*^9, 3.43615383990625*^9}, {3.43617970259375*^9, 
   3.43617973140625*^9}, {3.436179807703125*^9, 3.43617983078125*^9}, 
   3.436179873875*^9, {3.436180041125*^9, 3.436180111828125*^9}, {
   3.436180170859375*^9, 3.436180202703125*^9}, 3.4361804628125*^9, {
   3.43618070028125*^9, 3.436180729234375*^9}, {3.436180784578125*^9, 
   3.436180787703125*^9}, {3.43618081934375*^9, 3.4361808206875*^9}, {
   3.436182400484375*^9, 3.43618242003125*^9}, {3.436182451453125*^9, 
   3.43618247978125*^9}, {3.436183495328125*^9, 3.43618357815625*^9}, {
   3.436183636609375*^9, 3.436183667859375*^9}, 3.4361837068125*^9, {
   3.436183804234375*^9, 3.436183819390625*^9}, {3.436183854703125*^9, 
   3.436183878875*^9}, {3.436183909828125*^9, 3.43618391665625*^9}, {
   3.436183962375*^9, 3.436183972609375*^9}, {3.436184829859375*^9, 
   3.43618485253125*^9}, {3.436184888984375*^9, 3.436184915078125*^9}, {
   3.436184958203125*^9, 3.436184987015625*^9}, {3.436185084015625*^9, 
   3.4361850891875*^9}, {3.43618516678125*^9, 3.43618516778125*^9}, {
   3.436185299328125*^9, 3.43618532703125*^9}, {3.436185419546875*^9, 
   3.436185424828125*^9}, {3.436185507203125*^9, 3.43618556134375*^9}, {
   3.436185732015625*^9, 3.43618576653125*^9}, {3.436185873703125*^9, 
   3.436185938078125*^9}, {3.436186011421875*^9, 3.4361861639375*^9}, 
   3.43618620303125*^9, {3.4361862476875*^9, 3.436186265234375*^9}, {
   3.43618641634375*^9, 3.43618648996875*^9}, {3.4361865425625*^9, 
   3.43618656596875*^9}, {3.436187115953125*^9, 3.43618719128125*^9}, {
   3.43618731028125*^9, 3.436187315953125*^9}, {3.436187350546875*^9, 
   3.436187380671875*^9}, {3.43618742546875*^9, 3.436187439765625*^9}, {
   3.436187474671875*^9, 3.436187475703125*^9}, {3.43618757446875*^9, 
   3.436187586640625*^9}, 3.436187665453125*^9, 3.436187708609375*^9, 
   3.436187789203125*^9, {3.43618786896875*^9, 3.436187873515625*^9}, {
   3.436187914453125*^9, 3.4361880935625*^9}, {3.436188155828125*^9, 
   3.4361881758125*^9}, {3.436188220546875*^9, 3.436188270484375*^9}, {
   3.43618836453125*^9, 3.436188366921875*^9}, {3.43618841178125*^9, 
   3.436188415578125*^9}, {3.4361901251157827`*^9, 3.436190127115898*^9}, {
   3.436190289468999*^9, 3.436190305157403*^9}, {3.436193638265625*^9, 
   3.436193687078125*^9}, {3.436194100234375*^9, 3.436194188125*^9}, {
   3.43619424946875*^9, 3.43619425071875*^9}, {3.4361942934375*^9, 
   3.43619429390625*^9}, {3.436194388796875*^9, 3.436194479625*^9}, {
   3.436194551375*^9, 3.436194656578125*^9}, {3.43619470359375*^9, 
   3.436194716359375*^9}, {3.436194859484375*^9, 3.436194907234375*^9}, {
   3.43619530746875*^9, 3.436195315375*^9}, 3.436195372265625*^9, {
   3.43619542871875*^9, 3.436195454078125*^9}, {3.43619548471875*^9, 
   3.436195503515625*^9}, {3.436195648796875*^9, 3.436195665078125*^9}, {
   3.4362033845*^9, 3.4362034043125*^9}, {3.436203474015625*^9, 
   3.436203567*^9}, {3.4362037476875*^9, 3.43620374840625*^9}, {
   3.436203785921875*^9, 3.43620384903125*^9}, {3.436204140296875*^9, 
   3.4362041898125*^9}, {3.43620425259375*^9, 3.436204257015625*^9}, {
   3.436204315890625*^9, 3.43620449453125*^9}, {3.43620453121875*^9, 
   3.436204562765625*^9}, {3.436204593375*^9, 3.436204626625*^9}, 
   3.43620535603125*^9, {3.436205436953125*^9, 3.43620543734375*^9}, {
   3.436206453234375*^9, 3.436206475828125*^9}, {3.43620676715625*^9, 
   3.436206803234375*^9}, {3.436206853953125*^9, 3.436206855171875*^9}, {
   3.43620689825*^9, 3.436206898703125*^9}, {3.436206944359375*^9, 
   3.436206952203125*^9}, {3.43620698996875*^9, 3.43620701534375*^9}, {
   3.43620707584375*^9, 3.43620707796875*^9}, {3.436207121265625*^9, 
   3.436207125265625*^9}, {3.4362072139375*^9, 3.43620731265625*^9}, {
   3.4362073581875*^9, 3.436207629453125*^9}, {3.43620766615625*^9, 
   3.436207719734375*^9}, {3.436245485328125*^9, 3.436245513421875*^9}, 
   3.436246866890625*^9, {3.436246932109375*^9, 3.43624693259375*^9}, {
   3.436246988*^9, 3.436247126265625*^9}, {3.436247274296875*^9, 
   3.43624727696875*^9}, {3.436247309*^9, 3.436247322765625*^9}, {
   3.436247354890625*^9, 3.43624736321875*^9}, {3.436247409328125*^9, 
   3.4362474585625*^9}, {3.436247534828125*^9, 3.436247552453125*^9}, {
   3.43624761878125*^9, 3.436247619453125*^9}, {3.436251617390625*^9, 
   3.436251656375*^9}, {3.436253398578125*^9, 3.4362534100625*^9}, {
   3.436254726625*^9, 3.436254744125*^9}, {3.436255219234375*^9, 
   3.436255228734375*^9}, {3.436255278390625*^9, 3.43625527928125*^9}, {
   3.43625532515625*^9, 3.436255346828125*^9}, {3.43625550109375*^9, 
   3.436255507625*^9}, {3.4362556296875*^9, 3.436255656484375*^9}, {
   3.4362557195*^9, 3.436255722359375*^9}, {3.43625577665625*^9, 
   3.43625578046875*^9}, {3.4362569176875*^9, 3.436256924734375*^9}, {
   3.4362737952291393`*^9, 3.436273817485365*^9}, {3.4362738712007356`*^9, 
   3.4362738935729723`*^9}, {3.4362742864822598`*^9, 
   3.4362745894915576`*^9}, {3.4362746804296503`*^9, 3.436274680467654*^9}, {
   3.436275243632965*^9, 3.436275263350937*^9}, {3.436275418151415*^9, 
   3.4362754396685667`*^9}, {3.436289169077794*^9, 3.436289184047023*^9}, {
   3.436289215454278*^9, 3.4362892201731787`*^9}, {3.43634839165625*^9, 
   3.436348392421875*^9}, 3.43634940971875*^9, {3.436349449296875*^9, 
   3.43634945759375*^9}, {3.436496196828125*^9, 3.436496197296875*^9}, {
   3.43649631153125*^9, 3.436496458953125*^9}, 3.436496503875*^9, {
   3.43649653834375*^9, 3.436496757046875*^9}, {3.43649678803125*^9, 
   3.436496819921875*^9}, {3.436496857765625*^9, 3.436496928390625*^9}, {
   3.43649705296875*^9, 3.43649718234375*^9}, {3.436497217203125*^9, 
   3.4364973613125*^9}, {3.436497395046875*^9, 3.436497476359375*^9}, {
   3.4364975285*^9, 3.436497828375*^9}, {3.436497863734375*^9, 
   3.436497914453125*^9}, {3.4364979874375*^9, 3.436497987625*^9}, {
   3.436498033203125*^9, 3.43649808821875*^9}, {3.436498145625*^9, 
   3.436498149828125*^9}, {3.436498191703125*^9, 3.436498337390625*^9}, {
   3.436498368515625*^9, 3.436498459578125*^9}, {3.43649849621875*^9, 
   3.436498506015625*^9}, {3.43649892778125*^9, 3.436498930984375*^9}, {
   3.43649896496875*^9, 3.436498968578125*^9}, {3.4364990521875*^9, 
   3.436499054828125*^9}, 3.43649909578125*^9, 3.436499156875*^9, {
   3.43649925721875*^9, 3.436499289015625*^9}, 3.436499339578125*^9, {
   3.436499506453125*^9, 3.4364995079375*^9}, {3.43649963984375*^9, 
   3.43649964303125*^9}, 3.43649977784375*^9, {3.436499827890625*^9, 
   3.43649990246875*^9}, {3.436499937375*^9, 3.436499997265625*^9}, {
   3.43650006409375*^9, 3.43650007090625*^9}, {3.43650011378125*^9, 
   3.4365001275*^9}, {3.436500178640625*^9, 3.436500296625*^9}, {
   3.436500336359375*^9, 3.436500390625*^9}, {3.436500454703125*^9, 
   3.436500490171875*^9}, {3.436500611984375*^9, 3.436500745015625*^9}, {
   3.43650077590625*^9, 3.43650077909375*^9}, {3.436500899875*^9, 
   3.43650090653125*^9}, {3.4365009889375*^9, 3.4365009924375*^9}, {
   3.436501100671875*^9, 3.43650111259375*^9}, {3.43650119528125*^9, 
   3.436501203640625*^9}, {3.43650123825*^9, 3.436501291296875*^9}, {
   3.43650133878125*^9, 3.43650137684375*^9}, {3.43650143865625*^9, 
   3.436501504*^9}, {3.436501536125*^9, 3.436501541125*^9}, {
   3.436501682375*^9, 3.436501694265625*^9}, {3.436501824828125*^9, 
   3.436501849015625*^9}, {3.4365019898125*^9, 3.43650199565625*^9}, {
   3.436502193984375*^9, 3.4365021956875*^9}, {3.436502293640625*^9, 
   3.43650234909375*^9}, 3.43650239709375*^9, 3.436502912515625*^9, {
   3.436503051171875*^9, 3.436503052484375*^9}, {3.436503109828125*^9, 
   3.436503110328125*^9}, {3.436503163703125*^9, 3.4365031839375*^9}, {
   3.436503214140625*^9, 3.436503225578125*^9}, {3.4365050618125*^9, 
   3.436505075359375*^9}, {3.436505124015625*^9, 3.43650512571875*^9}, 
   3.436505183984375*^9, {3.4365052371875*^9, 3.436505242359375*^9}, 
   3.4365053135*^9, {3.4365054159375*^9, 3.43650548796875*^9}, {
   3.4365055679375*^9, 3.43650559075*^9}, 3.43650565653125*^9, {
   3.436505711359375*^9, 3.436505745125*^9}, {3.436505780984375*^9, 
   3.436505782640625*^9}, {3.436513382734375*^9, 3.436513383828125*^9}, {
   3.436513431734375*^9, 3.436513478265625*^9}, {3.43651354553125*^9, 
   3.436513583578125*^9}, {3.436513636609375*^9, 3.436513660671875*^9}, {
   3.43651695165625*^9, 3.436516964171875*^9}, {3.4365391605625*^9, 
   3.436539161390625*^9}, {3.43653925725*^9, 3.436539273390625*^9}, {
   3.436539373890625*^9, 3.43653937953125*^9}, {3.436539410921875*^9, 
   3.436539413203125*^9}, {3.43653970384375*^9, 3.436539705078125*^9}, {
   3.43653977790625*^9, 3.436539789109375*^9}, {3.436539835703125*^9, 
   3.436539870859375*^9}, {3.436539901015625*^9, 3.43653994540625*^9}, {
   3.436539990984375*^9, 3.43654001634375*^9}, 3.436540147734375*^9, 
   3.436540193859375*^9, {3.43654023321875*^9, 3.436540247125*^9}, {
   3.4365402996875*^9, 3.436540402625*^9}, {3.43654043390625*^9, 
   3.43654044059375*^9}, {3.436540557859375*^9, 3.436540594296875*^9}, {
   3.436540719578125*^9, 3.436540818546875*^9}, {3.4365409223125*^9, 
   3.436540968640625*^9}, {3.436541022953125*^9, 3.436541023296875*^9}, {
   3.45602462953125*^9, 3.456024664828125*^9}, {3.4560247026875*^9, 
   3.456024721578125*^9}, {3.456025369953125*^9, 3.456025401890625*^9}, {
   3.4560254400625*^9, 3.456025454546875*^9}, {3.4560255106875*^9, 
   3.456025537109375*^9}, {3.456025570625*^9, 3.456025585859375*^9}, {
   3.45602563040625*^9, 3.45602569159375*^9}},
 CellID->290373291],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`aa$$ = 0.5, $CellContext`bb$$ = 
    0, $CellContext`IC$$ = {{0.0050000000000000044`, 
    0.97}}, $CellContext`kk$$ = 
    2, $CellContext`ode$$ = -$CellContext`k (
     1 - $CellContext`x) $CellContext`x, $CellContext`T$$ = 
    4.6, $CellContext`xmax$$ = 1, $CellContext`xmin$$ = 0, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ode$$], -$CellContext`k (
        1 - $CellContext`x) $CellContext`x, "x'=="}}, {
      Hold[
       Style["parameters", Bold]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`kk$$], 2, "k"}, 0, 3}, {{
       Hold[$CellContext`aa$$], 0.5, "a"}, 0, 3}, {{
       Hold[$CellContext`bb$$], 0, "b"}, 0, 3}, {{
       Hold[$CellContext`T$$], 10.}, 1, 30.}, {{
       Hold[$CellContext`xmin$$], 0, 
       "\!\(\*SubscriptBox[\(x\), \(min\)]\)"}, -10, 10.}, {{
       Hold[$CellContext`xmax$$], 1, "\!\(\*SubscriptBox[\(x\), \(max\)]\)"}, 
      Dynamic[$CellContext`xmin$$ + 1], 10.}, {
      Hold[
       Style["initial conditions:", Bold]], 
      Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Style["      Alt-Click to create locators"]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`IC$$], {}}, Automatic}}, Typeset`size$$ = {
    500., {147.5, 152.5}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`kk$20732$$ = 
    0, $CellContext`aa$20733$$ = 0, $CellContext`bb$20734$$ = 
    0, $CellContext`T$20735$$ = 0, $CellContext`xmin$20736$$ = 
    0, $CellContext`xmax$20737$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`aa$$ = 0.5, $CellContext`bb$$ = 
        0, $CellContext`IC$$ = {}, $CellContext`kk$$ = 
        2, $CellContext`ode$$ = -$CellContext`k (
          1 - $CellContext`x) $CellContext`x, $CellContext`T$$ = 
        10., $CellContext`xmax$$ = 1, $CellContext`xmin$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`kk$$, $CellContext`kk$20732$$, 0], 
        Hold[$CellContext`aa$$, $CellContext`aa$20733$$, 0], 
        Hold[$CellContext`bb$$, $CellContext`bb$20734$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$20735$$, 0], 
        Hold[$CellContext`xmin$$, $CellContext`xmin$20736$$, 0], 
        Hold[$CellContext`xmax$$, $CellContext`xmax$20737$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        Block[{$CellContext`eqn, $CellContext`u, $CellContext`t, \
$CellContext`equilib, $CellContext`sol, $CellContext`t0, $CellContext`x0, \
$CellContext`x, $CellContext`k, $CellContext`a, $CellContext`b}, \
$CellContext`eqn := 
          ReplaceAll[$CellContext`ode$$, {$CellContext`x -> $CellContext`u, \
$CellContext`k -> $CellContext`kk$$, $CellContext`a -> $CellContext`aa$$, \
$CellContext`b -> $CellContext`bb$$}]; $CellContext`equilib := 
          Solve[$CellContext`eqn == 0, $CellContext`u]; 
         Clear[$CellContext`x0, $CellContext`t0]; $CellContext`sol[{
             Pattern[$CellContext`t0, 
              Blank[]], 
             Pattern[$CellContext`x0, 
              Blank[]]}] := Part[
            
            DSolve[{Derivative[1][$CellContext`u][$CellContext`t] == 
              ReplaceAll[$CellContext`eqn, $CellContext`u :> \
$CellContext`u[$CellContext`t]], $CellContext`u[$CellContext`t0] == \
$CellContext`x0}, 
             $CellContext`u[$CellContext`t], $CellContext`t], 1]; Pane[
           Grid[{{
              Show[
               Graphics[
                Thickness[0.01]], 
               Plot[
                Evaluate[
                 
                 ReplaceAll[$CellContext`u, $CellContext`equilib]], \
{$CellContext`t, 0., $CellContext`T$$}, 
                PlotRange -> {$CellContext`xmin$$, $CellContext`xmax$$}], 
               Map[Plot[
                 Evaluate[
                  ReplaceAll[
                   $CellContext`u[$CellContext`t], 
                   $CellContext`sol[#]]], {$CellContext`t, 
                  Part[#, 1], $CellContext`T$$}, ColorFunction -> (Hue[#2]& ),
                  ColorFunctionScaling -> False, 
                 PlotRange -> {$CellContext`xmin$$, $CellContext`xmax$$}]& , \
$CellContext`IC$$], 
               Graphics[
                Directive[{
                  Thickness[0.005], 
                  Hue[0.7, 0.2, 0.7, 0.4]}]], 
               VectorPlot[{1, 
                 Evaluate[$CellContext`eqn]}, {$CellContext`t, 
                 0, $CellContext`T$$}, {$CellContext`u, $CellContext`xmin$$, \
$CellContext`xmax$$}, Axes -> True, AxesLabel -> {"t", "x"}, VectorPoints -> 
                15, VectorScale -> Medium], Axes -> True, 
               AxesLabel -> {"t", "x"}, ImageSize -> {300, 300}, 
               PlotRange -> {$CellContext`xmin$$, $CellContext`xmax$$}, 
               AspectRatio -> 1/GoldenRatio], 
              Spacer[10], 
              Column[{
                Text[
                 Column[
                  Prepend[
                   Which[Length[$CellContext`IC$$] > 0, 
                    Simplify[
                    ReplaceAll[
                    $CellContext`u[$CellContext`t], 
                    Map[$CellContext`sol, $CellContext`IC$$]]], True, 
                    ReplaceAll[
                    $CellContext`u[$CellContext`t], 
                    
                    DSolve[{
                    Derivative[1][$CellContext`u][$CellContext`t] == 
                    ReplaceAll[$CellContext`eqn, $CellContext`u :> \
$CellContext`u[$CellContext`t]], $CellContext`u[$CellContext`t0] == \
$CellContext`x0}, 
                    $CellContext`u[$CellContext`t], $CellContext`t]]], 
                   "solutions: \n"]]], 
                Spacer[10], 
                Text[
                 Column[
                  Flatten[{"Equilibria: \n", $CellContext`equilib}]]]}]}}], {
           500, 300}, Alignment -> Center]]], 
      "Specifications" :> {{{$CellContext`ode$$, -$CellContext`k (
           1 - $CellContext`x) $CellContext`x, "x'=="}, ControlType -> 
         InputField}, 
        Style[
        "parameters", Bold], {{$CellContext`kk$$, 2, "k"}, 0, 3, Appearance -> 
         "Labeled", ImageSize -> Tiny}, {{$CellContext`aa$$, 0.5, "a"}, 0, 3, 
         Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`bb$$, 0, "b"}, 0, 3, Appearance -> "Labeled", 
         ImageSize -> Tiny}, 
        Delimiter, {{$CellContext`T$$, 10.}, 1, 30., Appearance -> "Labeled", 
         ImageSize -> 
         Tiny}, {{$CellContext`xmin$$, 0, 
          "\!\(\*SubscriptBox[\(x\), \(min\)]\)"}, -10, 10., Appearance -> 
         "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`xmax$$, 1, 
          "\!\(\*SubscriptBox[\(x\), \(max\)]\)"}, 
         Dynamic[$CellContext`xmin$$ + 1], 10., Appearance -> "Labeled", 
         ImageSize -> Tiny}, Delimiter, 
        Style["initial conditions:", Bold], 
        Style[
        "      Alt-Click to create locators"], {{$CellContext`IC$$, {}}, 
         Automatic, ControlType -> Locator, LocatorAutoCreate -> True}}, 
      "Options" :> {
       ControlPlacement -> Left, AutorunSequencing -> {3, 4, 5, 6, 7, 8, 9}, 
        Deployed -> True}, "DefaultOptions" :> {}],
     ImageSizeCache->{777., {180., 185.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`ODESolve0[
          Pattern[$CellContext`xdot, 
           Blank[List]], 
          Pattern[$CellContext`xvar, 
           Blank[List]], 
          Pattern[$CellContext`icond, 
           Blank[List]], {
           Pattern[$CellContext`t, 
            Blank[]], 
           Pattern[$CellContext`t0, 
            Blank[]], 
           Pattern[$CellContext`T, 
            Blank[]]}, 
          Pattern[$CellContext`opt, 
           BlankNullSequence[]]] := Module[{}, 
          Return[
           ReplaceAll[
            (ReplaceAll[$CellContext`xvar, 
             Map[# -> #[$CellContext`t]& , #]]& )[$CellContext`xvar], 
            First[
             NDSolve[
              Join[
               Table[Derivative[1][
                  
                  Part[$CellContext`xvar, $CellContext`i]][$CellContext`t] == \
(ReplaceAll[
                  Part[$CellContext`xdot, $CellContext`i], 
                  
                  Map[# -> #[$CellContext`t]& , #]]& )[$CellContext`xvar], \
{$CellContext`i, 1, 
                 Length[$CellContext`xvar]}], 
               Table[
               Part[$CellContext`xvar, $CellContext`i][$CellContext`t0] == 
                Part[$CellContext`icond, $CellContext`i], {$CellContext`i, 1, 
                 
                 Length[$CellContext`xvar]}]], $CellContext`xvar, \
{$CellContext`t, $CellContext`t0, $CellContext`T}, $CellContext`opt]]]]]; \
$CellContext`ODESolve[
          Pattern[$CellContext`xdot, 
           Blank[List]], 
          Pattern[$CellContext`xvar, 
           Blank[List]], 
          Pattern[$CellContext`ictab, 
           Blank[List]], {
           Pattern[$CellContext`t, 
            Blank[]], 
           Pattern[$CellContext`t0, 
            Blank[]], 
           Pattern[$CellContext`T, 
            Blank[]]}, 
          Pattern[$CellContext`opt, 
           BlankNullSequence[]]] := 
        Map[$CellContext`ODESolve0[$CellContext`xdot, $CellContext`xvar, #, \
{$CellContext`t, $CellContext`t0, $CellContext`T}, $CellContext`opt]& , \
$CellContext`ictab]; Null}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.45599204734375*^9, 3.456024669109375*^9, 3.45602472340625*^9, {
   3.456025375015625*^9, 3.456025403078125*^9}, 3.456025456796875*^9, {
   3.456025512109375*^9, 3.456025540265625*^9}, 3.456025587265625*^9, 
   3.456025632546875*^9, {3.456025663203125*^9, 3.4560256928125*^9}}]
}, {2}]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{885, 566},
WindowMargins->{{34, Automatic}, {Automatic, 5}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 127, 2, 49, "Subtitle"],
Cell[CellGroupData[{
Cell[719, 28, 27275, 526, 1392, "Input",
 CellID->290373291],
Cell[27997, 556, 10391, 224, 382, "Output"]
}, {2}]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
