(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18875,        470]
NotebookOptionsPosition[     17958,        434]
NotebookOutlinePosition[     18429,        452]
CellTagsIndexPosition[     18386,        449]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Modeling of the Drug Concentration in the Blood by Repeated Intravascular \
Dosing\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Grid", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(min\)]\)=\>\"", ",", 
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{"c0", " ", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"ke", " ", "\[Tau]"}]]}], 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"ke", " ", "\[Tau]"}]]}]], "-", "c0"}], ",", "3"}], 
            "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(max\)]\)=\>\"", ",", 
           RowBox[{"N", "[", 
            RowBox[{
             FractionBox[
              RowBox[{"c0", " ", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ke", " ", "\[Tau]"}]]}], 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"ke", " ", "\[Tau]"}]]}]], ",", "3"}], "]"}]}], 
          "}"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Spacer", "[", "20", "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"c00", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "ke"}], " ", "t"}]]}], "+", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            RowBox[{"c0", " ", 
             RowBox[{"UnitStep", "[", 
              RowBox[{"t", "-", 
               RowBox[{"i", " ", "\[Tau]"}]}], "]"}], 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "ke"}], " ", 
               RowBox[{"(", 
                RowBox[{"t", "-", 
                 RowBox[{"i", " ", "\[Tau]"}]}], ")"}]}]]}]}]}], ",", 
          FractionBox[
           RowBox[{"c0", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ke", " ", "\[Tau]"}]]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ke", " ", "\[Tau]"}]]}]], ",", 
          RowBox[{
           FractionBox[
            RowBox[{"c0", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"ke", " ", "\[Tau]"}]]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"ke", " ", "\[Tau]"}]]}]], "-", "c0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "72"}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "range"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"300", ",", "200"}], "}"}]}], ",", 
        RowBox[{"Exclusions", "\[Rule]", "None"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<t\>\"", ",", "\"\<c\>\""}], "}"}]}]}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ke", ",", "0.01", ",", 
       "\"\<Rate of elimination (\!\(\*SubscriptBox[\(k\), \(e\)]\))\>\""}], 
      "}"}], ",", "0.01", ",", "2", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c00", ",", "0", ",", "\"\<First dose\>\""}], "}"}], ",", "0", 
     ",", "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\"\<Repeated dosing\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", "1", ",", "48", ",", "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c0", ",", "0", ",", "\"\<Dose\>\""}], "}"}], ",", "0", ",", 
     "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "50", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "range", ",", "1", ",", 
       "\"\<PlotRange \!\(\*SubscriptBox[\(c\), \(max\)]\)\>\""}], "}"}], ",", 
     RowBox[{"10", "^", 
      RowBox[{"(", 
       RowBox[{"-", "10"}], ")"}]}], ",", "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4234616526833344`*^9, 3.4234616707893696`*^9}, {
   3.4234617117682943`*^9, 3.423461890795723*^9}, 3.4234619809854097`*^9, {
   3.4234620289543858`*^9, 3.4234620380474606`*^9}, {3.423462196284995*^9, 
   3.4234622054982433`*^9}, {3.4234622573227634`*^9, 
   3.4234622661855073`*^9}, {3.4234622979511843`*^9, 3.423462316618026*^9}, {
   3.4234628320291505`*^9, 3.423462918763869*^9}, {3.4234629503593006`*^9, 
   3.4234630161338797`*^9}, {3.423463198265773*^9, 3.4234632144891005`*^9}, {
   3.4234632775998497`*^9, 3.4234632813252068`*^9}, {3.4234633788854914`*^9, 
   3.4234635045061245`*^9}, {3.4234635595753107`*^9, 3.423463577791504*^9}, {
   3.4234636845450077`*^9, 3.423463686367629*^9}, {3.4234638460372224`*^9, 
   3.4234639149663377`*^9}, {3.4235041035668736`*^9, 3.42350410754259*^9}, {
   3.4240185805566587`*^9, 3.424018586875745*^9}, {3.424018765953246*^9, 
   3.4240187839691515`*^9}, {3.424018850544883*^9, 3.424018937099342*^9}, {
   3.4240190365623627`*^9, 3.4240190539974327`*^9}, {3.424019088947689*^9, 
   3.4240191070937815`*^9}, {3.42401914234447*^9, 3.424019143105564*^9}, {
   3.4240200968569913`*^9, 3.4240201270003357`*^9}, {3.4254537174033856`*^9, 
   3.425453728068722*^9}, {3.425453820211216*^9, 3.4254538583059936`*^9}, {
   3.4254541799384785`*^9, 3.425454224542616*^9}, {3.425454267133859*^9, 
   3.4254543482404847`*^9}, {3.455991205109375*^9, 3.45599122240625*^9}, {
   3.455991460375*^9, 3.45599154628125*^9}},
 CellID->178778280],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c0$$ = 0, $CellContext`c00$$ = 
    1., $CellContext`ke$$ = 0.53, $CellContext`n$$ = 0, $CellContext`range$$ =
     1, $CellContext`\[Tau]$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ke$$], 0.01, 
       "Rate of elimination (\!\(\*SubscriptBox[\(k\), \(e\)]\))"}, 0.01, 
      2}, {{
       Hold[$CellContext`c00$$], 0, "First dose"}, 0, 1}, {
      Hold["Repeated dosing"], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[$CellContext`\[Tau]$$], 1, 48, 1}, {{
       Hold[$CellContext`c0$$], 0, "Dose"}, 0, 1}, {
      Hold[$CellContext`n$$], 0, 50}, {{
       Hold[$CellContext`range$$], 1, 
       "PlotRange \!\(\*SubscriptBox[\(c\), \(max\)]\)"}, 
      Rational[1, 10000000000], 1}}, Typeset`size$$ = {461.5, {339., 21.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`ke$50077$$ = 0, $CellContext`c00$50078$$ = 
    0, $CellContext`\[Tau]$50079$$ = 0, $CellContext`c0$50080$$ = 
    0, $CellContext`n$50081$$ = 0, $CellContext`range$50082$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c0$$ = 0, $CellContext`c00$$ = 
        0, $CellContext`ke$$ = 0.01, $CellContext`n$$ = 
        0, $CellContext`range$$ = 1, $CellContext`\[Tau]$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`ke$$, $CellContext`ke$50077$$, 0], 
        Hold[$CellContext`c00$$, $CellContext`c00$50078$$, 0], 
        Hold[$CellContext`\[Tau]$$, $CellContext`\[Tau]$50079$$, 0], 
        Hold[$CellContext`c0$$, $CellContext`c0$50080$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$50081$$, 0], 
        Hold[$CellContext`range$$, $CellContext`range$50082$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[{
         Grid[{{"\!\(\*SubscriptBox[\(c\), \(min\)]\)=", 
            
            N[$CellContext`c0$$ (
               E^($CellContext`ke$$ $CellContext`\[Tau]$$)/(-1 + 
               E^($CellContext`ke$$ $CellContext`\[Tau]$$))) - \
$CellContext`c0$$, 3]}, {"\!\(\*SubscriptBox[\(c\), \(max\)]\)=", 
            
            N[$CellContext`c0$$ (
              E^($CellContext`ke$$ $CellContext`\[Tau]$$)/(-1 + 
              E^($CellContext`ke$$ $CellContext`\[Tau]$$))), 3]}}], 
         Spacer[20], 
         Plot[{$CellContext`c00$$ E^((-$CellContext`ke$$) $CellContext`t) + 
           Sum[($CellContext`c0$$ 
              UnitStep[$CellContext`t - $CellContext`i $CellContext`\[Tau]$$])
               E^((-$CellContext`ke$$) ($CellContext`t - $CellContext`i \
$CellContext`\[Tau]$$)), {$CellContext`i, 
              1, $CellContext`n$$}], $CellContext`c0$$ (
            E^($CellContext`ke$$ $CellContext`\[Tau]$$)/(-1 + 
            E^($CellContext`ke$$ $CellContext`\[Tau]$$))), $CellContext`c0$$ (
             E^($CellContext`ke$$ $CellContext`\[Tau]$$)/(-1 + 
             E^($CellContext`ke$$ $CellContext`\[Tau]$$))) - \
$CellContext`c0$$}, {$CellContext`t, 0, 72}, 
          PlotRange -> {0, $CellContext`range$$}, ImageSize -> {300, 200}, 
          Exclusions -> None, AxesLabel -> {"t", "c"}]}], 
      "Specifications" :> {{{$CellContext`ke$$, 0.01, 
          "Rate of elimination (\!\(\*SubscriptBox[\(k\), \(e\)]\))"}, 0.01, 
         2, ImageSize -> Small}, {{$CellContext`c00$$, 0, "First dose"}, 0, 1,
          ImageSize -> Small}, 
        "Repeated dosing", {$CellContext`\[Tau]$$, 1, 48, 1, ImageSize -> 
         Small}, {{$CellContext`c0$$, 0, "Dose"}, 0, 1, ImageSize -> 
         Small}, {$CellContext`n$$, 0, 50, ImageSize -> Small}, 
        Delimiter, {{$CellContext`range$$, 1, 
          "PlotRange \!\(\*SubscriptBox[\(c\), \(max\)]\)"}, 
         Rational[1, 10000000000], 1, ImageSize -> Small}}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{941., {219., 226.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.423461893539669*^9, 3.423461982767973*^9, 3.423462041632616*^9, 
   3.4234622066298704`*^9, 3.4234622667362995`*^9, 3.423462317809739*^9, {
   3.423462861992235*^9, 3.423462919384762*^9}, {3.423462986010565*^9, 
   3.423463018587408*^9}, 3.423463218775264*^9, 3.4234632819460993`*^9, {
   3.4234634798006*^9, 3.423463505757925*^9}, 3.423463578512541*^9, 
   3.4234636875292993`*^9, {3.4234638651647263`*^9, 3.4234639163383102`*^9}, 
   3.423504108113411*^9, 3.4239726778851585`*^9, 3.4240185888185387`*^9, 
   3.424018942166628*^9, 3.424019055649809*^9, 3.4240191109893837`*^9, 
   3.4240191439367595`*^9, {3.424020103937172*^9, 3.4240201280518475`*^9}, 
   3.4254538661873264`*^9, 3.425454350013034*^9, 3.455991245734375*^9, {
   3.45599147615625*^9, 3.455991503953125*^9}, 3.455991547109375*^9}]
}, {2}]],

Cell[CellGroupData[{

Cell["Description", "Section",
 CellChangeTimes->{{3.4559897851875*^9, 3.455989790390625*^9}}],

Cell["\<\
Interactive tool to investigate the model of the blood level curve (mass of \
the drug in the blood) under repeated dosing described by the simple \
impulsive system:\
\>", "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4240192663728137`*^9, 3.4240193173861675`*^9}, {
   3.4254514888488817`*^9, 3.425451490561344*^9}, {3.4254539568777328`*^9, 
   3.4254540157423763`*^9}, {3.4254540460159073`*^9, 
   3.4254541206732593`*^9}, {3.436294648265625*^9, 3.436294653265625*^9}, {
   3.436294695421875*^9, 3.436294747921875*^9}, 3.43629527096875*^9, {
   3.436295312484375*^9, 3.436295316140625*^9}, {3.43629628190625*^9, 
   3.436296283203125*^9}, {3.456024815765625*^9, 3.456024859890625*^9}, {
   3.45602499015625*^9, 3.456024990671875*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"m", "'"}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["k", "e"]}], "m", " "}]}], TraditionalForm]], "InlineMath"],
 " if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "\[NotEqual]", 
    RowBox[{"n", " ", "\[Tau]"}]}], TraditionalForm]], "InlineMath"],
 ";  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"c", "(", "0", ")"}], "=", 
    SubscriptBox["c", "00"]}], TraditionalForm]], "InlineMath"],
 " \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"m", "(", 
     RowBox[{
      RowBox[{"n", " ", "\[Tau]"}], "+", "0"}], ")"}], "=", 
    RowBox[{
     RowBox[{"m", "(", 
      RowBox[{
       RowBox[{"n", " ", "\[Tau]"}], "-", "0"}], ")"}], "+", 
     SubscriptBox["m", "0"]}]}], TraditionalForm]], "InlineMath"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", "1"}], ",", " ", "2", ",", " ", "..."}], 
    ")"}], TraditionalForm]], "InlineMath"],
 " "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424019328552223*^9, 3.4240195879852695`*^9}, {
   3.455991578984375*^9, 3.455991604328125*^9}, {3.456024916859375*^9, 
   3.45602492628125*^9}},
 CellID->648775985],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", 
    RowBox[{"m", "(", "t", ")"}]}], TraditionalForm]], "InlineMath"],
 " (typically given in ",
 Cell[BoxData[
  FormBox["mg", TraditionalForm]], "InlineMath"],
 ") is the concentration of the drug in the blood depending on the time, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "e"], TraditionalForm]], "InlineMath"],
 " is the rate of elimination of the drug (found experimentally), ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "00"], TraditionalForm]], "InlineMath"],
 " is the first dose, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "0"], TraditionalForm]], "InlineMath"],
 " is the repeated dose, both are given in mg. The time between the doses is \
\[Tau] typically given in minutes or hours. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "min"], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "max"], TraditionalForm]], "InlineMath"],
 " are the extremal values of the asymtotically stable periodic equilibrium. "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4240195902985964`*^9, 3.424019717281188*^9}, {
   3.4240197613745914`*^9, 3.424019783366214*^9}, {3.424019820299321*^9, 
   3.4240198829894648`*^9}, {3.4254513065167007`*^9, 
   3.4254513119645343`*^9}, {3.4254513618362465`*^9, 3.425451458745595*^9}, {
   3.42545152876628*^9, 3.4254515313700237`*^9}, {3.425452046460688*^9, 
   3.425452061412187*^9}, {3.4254539479549026`*^9, 3.425453948625867*^9}, {
   3.436295254984375*^9, 3.436295283671875*^9}, {3.436295395375*^9, 
   3.436295468234375*^9}, {3.4362955540625*^9, 3.436295555828125*^9}, {
   3.456024933109375*^9, 3.45602493790625*^9}, {3.45602496815625*^9, 
   3.4560249779375*^9}},
 CellID->143509364]
}, Open  ]],

Cell[CellGroupData[{

Cell["Details", "Section",
 CellChangeTimes->{{3.455989799109375*^9, 3.45598980034375*^9}}],

Cell[TextData[{
 "This model can be used for drugs with elimination of first order, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"m", "'"}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["k", "e"]}], "m", " "}]}], TraditionalForm]], "InlineMath"],
 ",  the speed of elimination is proportional to the concentration. The rate \
of elimination is given to every drug by experiments. The explicite formulas \
are obtained by solving the given impulsive system. In the practice,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "min"], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "max"], TraditionalForm]], "InlineMath"],
 " must be inside the so called region of therapy to avoid over- and \
underdosing. This model (using the same notations) is part of the Biopharmacy \
courses for Pharmacy students. "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424020504933777*^9, 3.4240205345063*^9}, {
   3.4254516036339345`*^9, 3.425451854654885*^9}, {3.4254519905202494`*^9, 
   3.4254520318596926`*^9}, {3.425452126005067*^9, 3.4254521395745792`*^9}, {
   3.4254535705121665`*^9, 3.4254535977713633`*^9}, {3.43629562753125*^9, 
   3.436295637984375*^9}, {3.436297065515625*^9, 3.43629707090625*^9}, {
   3.456025000609375*^9, 3.4560250105*^9}},
 TextJustification->1.,
 CellID->616437312]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1108, 789},
WindowMargins->{{55, Automatic}, {Automatic, 7}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 110, 3, 117, "Subtitle"],
Cell[CellGroupData[{
Cell[702, 29, 6401, 151, 448, "Input",
 CellID->178778280],
Cell[7106, 182, 5430, 97, 469, "Output"]
}, {2}]],
Cell[CellGroupData[{
Cell[12570, 284, 94, 1, 105, "Section"],
Cell[12667, 287, 755, 13, 66, "Text"],
Cell[13425, 302, 1218, 44, 66, "Text",
 CellID->648775985],
Cell[14646, 348, 1787, 43, 115, "Text",
 CellID->143509364]
}, Open  ]],
Cell[CellGroupData[{
Cell[16470, 396, 91, 1, 105, "Section"],
Cell[16564, 399, 1366, 31, 115, "Text",
 CellID->616437312]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
