(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     34279,        835]
NotebookOptionsPosition[     33387,        798]
NotebookOutlinePosition[     33758,        814]
CellTagsIndexPosition[     33715,        811]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Modeling of the Drug Concentration in the Blood by Repeated Intravascular \
Dosing\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c12Step", ",", "c12all", ",", "c10", ",", "c20", ",", "IC", ",", "sol",
        ",", "t", ",", "i", ",", "c1min", ",", "c1max", ",", "c2min", ",", 
       "c2max"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"sol", "[", 
        RowBox[{"{", 
         RowBox[{"c10_", ",", "c20_"}], "}"}], "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c10", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "ka"}], " ", "t"}]]}], ",", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"ka", "+", "ke"}], ")"}]}], " ", "t"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "c10"}], " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"ke", " ", "t"}]], " ", "ka"}], "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"ka", " ", "t"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"c10", "+", "c20"}], ")"}], " ", "ka"}], "-", 
                RowBox[{"c20", " ", "ke"}]}], ")"}]}]}], ")"}]}], 
          RowBox[{"ka", "-", "ke"}]]}], "}"}]}], ";", 
      RowBox[{
       RowBox[{"c12Step", "[", 
        RowBox[{"{", 
         RowBox[{"c10_", ",", "c20_"}], "}"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sol", "[", 
           RowBox[{"{", 
            RowBox[{"c10", ",", "c20"}], "}"}], "]"}], "/.", 
          RowBox[{"t", "\[Rule]", "\[Tau]"}]}], ")"}], "+", 
        RowBox[{"{", 
         RowBox[{"c0", ",", "0"}], "}"}]}]}], ";", 
      RowBox[{"IC", "=", 
       RowBox[{"NestList", "[", 
        RowBox[{"c12Step", ",", 
         RowBox[{"{", 
          RowBox[{"c00", ",", "0"}], "}"}], ",", 
         RowBox[{"Floor", "[", 
          RowBox[{"T", "/", "\[Tau]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"c12all", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Which", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"i", "-", "1"}], ")"}], " ", "\[Tau]"}], 
               "\[LessEqual]", "t", "\[LessEqual]", 
               RowBox[{"i", " ", "\[Tau]"}]}], ",", "1", ",", "True", ",", 
              "0"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"sol", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"IC", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{"IC", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], "/.",
               " ", 
              RowBox[{"{", 
               RowBox[{"t", "\[Rule]", 
                RowBox[{"t", "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "-", "1"}], ")"}], " ", "\[Tau]"}]}]}], 
               "}"}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "IC", "]"}]}], "}"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"c1min", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"c0", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"ka", " ", "\[Tau]"}]]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"ka", " ", "\[Tau]"}]]}]], "-", "c0"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"c1max", "=", 
       FractionBox[
        RowBox[{"c0", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ka", " ", "\[Tau]"}]]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ka", " ", "\[Tau]"}]]}]]}], ";", "\[IndentingNewLine]", 
      RowBox[{"c2min", "=", 
       FractionBox[
        RowBox[{"c0", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ka", " ", "\[Tau]"}]], "-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ke", " ", "\[Tau]"}]]}], ")"}], " ", "ka"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ka", " ", "\[Tau]"}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"ke", " ", "\[Tau]"}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"ka", "-", "ke"}], ")"}]}]]}], ";", "\[IndentingNewLine]", 
      RowBox[{"c2max", "=", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"ka", "-", "ke"}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ka", "+", "ke"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ka", " ", "\[Tau]"}], "-", 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ka", " ", "\[Tau]"}]]}], ")"}], " ", "ke", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"Coth", "[", 
                    FractionBox[
                    RowBox[{"ke", " ", "\[Tau]"}], "2"], "]"}]}], ")"}]}], 
                RowBox[{"2", " ", "ka"}]], "]"}]}], ")"}]}], 
           RowBox[{"ka", "-", "ke"}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"c0", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ka", " ", "\[Tau]"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"ka", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"ka", " ", "\[Tau]"}], "-", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ka", " ", "\[Tau]"}]]}], ")"}], " ", "ke", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Coth", "[", 
                    FractionBox[
                    RowBox[{"ke", " ", "\[Tau]"}], "2"], "]"}]}], ")"}]}], 
                    RowBox[{"2", " ", "ka"}]], "]"}]}], ")"}]}], 
                RowBox[{"ka", "-", "ke"}]]], "-", 
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"ke", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"ka", " ", "\[Tau]"}], "-", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ka", " ", "\[Tau]"}]]}], ")"}], " ", "ke", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Coth", "[", 
                    FractionBox[
                    RowBox[{"ke", " ", "\[Tau]"}], "2"], "]"}]}], ")"}]}], 
                    RowBox[{"2", " ", "ka"}]], "]"}]}], ")"}]}], 
                RowBox[{"ka", "-", "ke"}]]]}], ")"}], " ", "ka"}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ka", " ", "\[Tau]"}]]}]], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "c0", " ", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"ka", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ka", " ", "\[Tau]"}], "-", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ka", " ", "\[Tau]"}]]}], ")"}], " ", "ke", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Coth", "[", 
                    FractionBox[
                    RowBox[{"ke", " ", "\[Tau]"}], "2"], "]"}]}], ")"}]}], 
                  RowBox[{"2", " ", "ka"}]], "]"}]}], ")"}]}], 
             RowBox[{"ka", "-", "ke"}]]], " ", "ka", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Coth", "[", 
              FractionBox[
               RowBox[{"ka", " ", "\[Tau]"}], "2"], "]"}], "-", 
             RowBox[{"Coth", "[", 
              FractionBox[
               RowBox[{"ke", " ", "\[Tau]"}], "2"], "]"}]}], ")"}]}]}], 
         ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Grid", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(1, min\)]\)=\>\"", ",", 
              RowBox[{"N", "[", 
               RowBox[{"c1min", ",", "3"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(1, max\)]\)=\>\"", ",", 
              RowBox[{"N", "[", 
               RowBox[{"c1max", ",", "3"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(2, min\)]\)=\>\"", ",", 
              RowBox[{"N", "[", 
               RowBox[{"c2min", ",", "3"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(2, max\)]\)=\>\"", ",", 
              RowBox[{"N", "[", 
               RowBox[{"c2max", ",", "3"}], "]"}]}], "}"}]}], "}"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Spacer", "[", "20", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"GraphicsColumn", "[", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Plot", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"c12all", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "c1min", ",", "c1max"}],
                "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "2"}], "}"}]}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "Automatic"}], ",", 
              RowBox[{"ImageSize", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"250", ",", "170"}], "}"}]}]}], "]"}], ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"Plot", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"c12all", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", "c2min", ",", "c2max"}],
                "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "2"}], "}"}]}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "Automatic"}], ",", 
              RowBox[{"Exclusions", "\[Rule]", "Automatic"}]}], "]"}]}], 
           "}"}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}]}], "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ka", ",", "1", ",", "\"\<\!\(\*SubscriptBox[\(k\), \(a\)]\)\>\""}], 
      "}"}], ",", "0.01", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ke", ",", "0.5", ",", "\"\<\!\(\*SubscriptBox[\(k\), \(e\)]\)\>\""}], 
      "}"}], ",", "0.005", ",", 
     RowBox[{"ka", "-", "0.01"}]}], "}"}], ",", "\"\<First dose\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c00", ",", "0", ",", "\"\<\!\(\*SubscriptBox[\(c\), \(1, 0\)]\)\>\""}],
       "}"}], ",", "0", ",", "2"}], "}"}], ",", "\"\<Repeated doses\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", "1", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c0", ",", "0", ",", "\"\<\!\(\*SubscriptBox[\(c\), \(0\)]\)\>\""}], 
      "}"}], ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", "10"}], "}"}], ",", "1", ",", "20"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4234616526833344`*^9, 3.4234616707893696`*^9}, {
   3.4234617117682943`*^9, 3.423461890795723*^9}, 3.4234619809854097`*^9, {
   3.4234620289543858`*^9, 3.4234620380474606`*^9}, {3.423462196284995*^9, 
   3.4234622054982433`*^9}, {3.4234622573227634`*^9, 
   3.4234622661855073`*^9}, {3.4234622979511843`*^9, 3.423462316618026*^9}, {
   3.4234628320291505`*^9, 3.423462918763869*^9}, {3.4234629503593006`*^9, 
   3.4234630161338797`*^9}, {3.423463198265773*^9, 3.4234632144891005`*^9}, {
   3.4234632775998497`*^9, 3.4234632813252068`*^9}, {3.4234633788854914`*^9, 
   3.4234635045061245`*^9}, {3.4234635595753107`*^9, 3.423463577791504*^9}, {
   3.4234636845450077`*^9, 3.423463686367629*^9}, {3.4234638460372224`*^9, 
   3.4234639149663377`*^9}, {3.423476039402851*^9, 3.4234760898754272`*^9}, {
   3.4234761205996065`*^9, 3.4234761531864643`*^9}, {3.4234761907805214`*^9, 
   3.4234763539551554`*^9}, {3.4234764172061057`*^9, 3.423476467428322*^9}, 
   3.423476518982453*^9, 3.4234765520199585`*^9, 3.4234766205585117`*^9, {
   3.423476693283085*^9, 3.4234767822009425`*^9}, 3.4234769752485313`*^9, {
   3.4234770278541746`*^9, 3.423477040662592*^9}, {3.4234771072683663`*^9, 
   3.4234771608754497`*^9}, {3.4234771961762094`*^9, 3.423477196356469*^9}, {
   3.423477305192968*^9, 3.4234773147467055`*^9}, {3.4234773449801793`*^9, 
   3.423477670488237*^9}, {3.423477702293971*^9, 3.423477797881419*^9}, {
   3.423478007703128*^9, 3.4234780389881134`*^9}, {3.423478248619549*^9, 
   3.423478295987661*^9}, {3.4234783584474735`*^9, 3.423478361571966*^9}, 
   3.4234784078384943`*^9, 3.423478438572688*^9, {3.4234785675982175`*^9, 
   3.4234785841019487`*^9}, {3.4234787352993603`*^9, 3.423478741498274*^9}, 
   3.423478966812259*^9, {3.4234791025574512`*^9, 3.423479203452531*^9}, {
   3.4234792957552557`*^9, 3.4234793471691856`*^9}, {3.4234793972812433`*^9, 
   3.4234794149366302`*^9}, 3.4234794588297453`*^9, {3.423479687017864*^9, 
   3.423479691684574*^9}, {3.423479861679014*^9, 3.4234798648635936`*^9}, {
   3.4234809919142127`*^9, 3.423480996831283*^9}, {3.423481122562075*^9, 
   3.42348112698844*^9}, {3.423482190037029*^9, 3.423482303660411*^9}, {
   3.4234823505077744`*^9, 3.4234823580686464`*^9}, {3.423482421589986*^9, 
   3.4234824455043726`*^9}, {3.423499198173264*^9, 3.423499393504136*^9}, {
   3.4234994338421392`*^9, 3.4234994353442993`*^9}, {3.4234994887310658`*^9, 
   3.4234994896023183`*^9}, {3.4234995448617773`*^9, 
   3.4234995770080013`*^9}, {3.4234997468321967`*^9, 3.423499773340314*^9}, {
   3.4234998069886975`*^9, 3.4234999041484065`*^9}, {3.4234999578656483`*^9, 
   3.423500000176488*^9}, {3.4235000609939394`*^9, 3.4235000672028675`*^9}, {
   3.4235002374376526`*^9, 3.423500283694166*^9}, 3.423500329159542*^9, {
   3.4235003884347763`*^9, 3.423500452907483*^9}, {3.423501654655512*^9, 
   3.423501701773264*^9}, {3.4235017384860544`*^9, 3.423501752295912*^9}, {
   3.4235018159274096`*^9, 3.42350185714668*^9}, 3.423502001173781*^9, {
   3.4235020418422594`*^9, 3.423502098864253*^9}, 3.423502202763653*^9, 
   3.4235022900792065`*^9, 3.423502337948038*^9, {3.4235023885708303`*^9, 
   3.4235024072476864`*^9}, {3.42350247262169*^9, 3.423502497046811*^9}, {
   3.4235025690503473`*^9, 3.4235025758000526`*^9}, {3.423502750911851*^9, 
   3.4235027985703807`*^9}, {3.423502832368981*^9, 3.423502857134592*^9}, {
   3.4235029092795725`*^9, 3.423502913385477*^9}, {3.423502978689379*^9, 
   3.423502985399027*^9}, {3.42350306021661*^9, 3.4235031366264815`*^9}, {
   3.4235031908444433`*^9, 3.423503191245019*^9}, {3.423503306210331*^9, 
   3.423503335672696*^9}, {3.424021687364028*^9, 3.424021687734561*^9}, {
   3.424021724617596*^9, 3.424021734101233*^9}, {3.4240218258731947`*^9, 
   3.4240218277058296`*^9}, {3.4240220479625435`*^9, 3.424022164970793*^9}, 
   3.424022199179983*^9, {3.4240223523602457`*^9, 3.4240223572072153`*^9}, {
   3.4240224177042055`*^9, 3.4240224217199802`*^9}, {3.42402259706211*^9, 
   3.4240226111223273`*^9}, {3.4240227249860554`*^9, 3.424022731385257*^9}, {
   3.4240827933772173`*^9, 3.4240827936075487`*^9}, {3.4240828305306416`*^9, 
   3.4240828316622686`*^9}, {3.424083381803333*^9, 3.424083447718114*^9}, {
   3.4276884554453726`*^9, 3.427688456396741*^9}, {3.4276885055774593`*^9, 
   3.4276885542574577`*^9}},
 CellID->410492984],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c0$$ = 1.24, $CellContext`c00$$ = 
    1.514, $CellContext`ka$$ = 0.858, $CellContext`ke$$ = 
    0.566438, $CellContext`T$$ = 16.96, $CellContext`\[Tau]$$ = 
    3.0300000000000002`, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ka$$], 1, "\!\(\*SubscriptBox[\(k\), \(a\)]\)"}, 
      0.01, 2}, {{
       Hold[$CellContext`ke$$], 0.5, "\!\(\*SubscriptBox[\(k\), \(e\)]\)"}, 
      0.005, 
      Dynamic[$CellContext`ka$$ - 0.01]}, {
      Hold["First dose"], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`c00$$], 0, "\!\(\*SubscriptBox[\(c\), \(1, 0\)]\)"}, 
      0, 2}, {
      Hold["Repeated doses"], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[$CellContext`\[Tau]$$], 1, 8}, {{
       Hold[$CellContext`c0$$], 0, "\!\(\*SubscriptBox[\(c\), \(0\)]\)"}, 0, 
      2}, {{
       Hold[$CellContext`T$$], 10}, 1, 20}}, Typeset`size$$ = {
    282.5, {425., 32.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`ka$25956$$ = 
    0, $CellContext`ke$25957$$ = 0, $CellContext`c00$25958$$ = 
    0, $CellContext`\[Tau]$25959$$ = 0, $CellContext`c0$25960$$ = 
    0, $CellContext`T$25961$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c0$$ = 0, $CellContext`c00$$ = 
        0, $CellContext`ka$$ = 1, $CellContext`ke$$ = 0.5, $CellContext`T$$ = 
        10, $CellContext`\[Tau]$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`ka$$, $CellContext`ka$25956$$, 0], 
        Hold[$CellContext`ke$$, $CellContext`ke$25957$$, 0], 
        Hold[$CellContext`c00$$, $CellContext`c00$25958$$, 0], 
        Hold[$CellContext`\[Tau]$$, $CellContext`\[Tau]$25959$$, 0], 
        Hold[$CellContext`c0$$, $CellContext`c0$25960$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$25961$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Block[{$CellContext`c12Step, $CellContext`c12all, $CellContext`c10, \
$CellContext`c20, $CellContext`IC, $CellContext`sol, $CellContext`t, \
$CellContext`i, $CellContext`c1min, $CellContext`c1max, $CellContext`c2min, \
$CellContext`c2max}, $CellContext`sol[{
            Pattern[$CellContext`c10$, 
             Blank[]], 
            Pattern[$CellContext`c20$, 
             Blank[]]}] = {$CellContext`c10$ 
           E^((-$CellContext`ka$$) $CellContext`t), 
           E^((-($CellContext`ka$$ + $CellContext`ke$$)) $CellContext`t) \
((((-$CellContext`c10$) 
               E^($CellContext`ke$$ $CellContext`t)) $CellContext`ka$$ + 
             E^($CellContext`ka$$ $CellContext`t) (($CellContext`c10$ + \
$CellContext`c20$) $CellContext`ka$$ - $CellContext`c20$ \
$CellContext`ke$$))/($CellContext`ka$$ - $CellContext`ke$$))}; \
$CellContext`c12Step[{
            Pattern[$CellContext`c10$, 
             Blank[]], 
            Pattern[$CellContext`c20$, 
             Blank[]]}] := ReplaceAll[
            $CellContext`sol[{$CellContext`c10$, $CellContext`c20$}], \
$CellContext`t -> $CellContext`\[Tau]$$] + {$CellContext`c0$$, 
            0}; $CellContext`IC = 
         NestList[$CellContext`c12Step, {$CellContext`c00$$, 0}, 
           
           Floor[$CellContext`T$$/$CellContext`\[Tau]$$]]; \
$CellContext`c12all = Apply[Plus, 
           Table[
           Which[($CellContext`i - 
                1) $CellContext`\[Tau]$$ <= $CellContext`t <= $CellContext`i \
$CellContext`\[Tau]$$, 1, True, 0] ReplaceAll[
              $CellContext`sol[{
                Part[$CellContext`IC, $CellContext`i, 1], 
                
                Part[$CellContext`IC, $CellContext`i, 
                 2]}], {$CellContext`t -> $CellContext`t - ($CellContext`i - 
                 1) $CellContext`\[Tau]$$}], {$CellContext`i, 1, 
             
             Length[$CellContext`IC]}]]; $CellContext`c1min = \
$CellContext`c0$$ (E^($CellContext`ka$$ $CellContext`\[Tau]$$)/(-1 + 
            E^($CellContext`ka$$ $CellContext`\[Tau]$$))) - $CellContext`c0$$; \
$CellContext`c1max = $CellContext`c0$$ (
           E^($CellContext`ka$$ $CellContext`\[Tau]$$)/(-1 + 
           E^($CellContext`ka$$ $CellContext`\[Tau]$$))); $CellContext`c2min = \
($CellContext`c0$$ (E^($CellContext`ka$$ $CellContext`\[Tau]$$) - 
            E^($CellContext`ke$$ $CellContext`\[Tau]$$))) \
($CellContext`ka$$/(((-1 + E^($CellContext`ka$$ $CellContext`\[Tau]$$)) (-1 + 
             E^($CellContext`ke$$ $CellContext`\[Tau]$$))) ($CellContext`ka$$ - \
$CellContext`ke$$))); $CellContext`c2max = ((
            1/($CellContext`ka$$ - $CellContext`ke$$)) 
           E^(-(($CellContext`ka$$ + $CellContext`ke$$) (($CellContext`ka$$ \
$CellContext`\[Tau]$$ - 
                Log[((-1 + 
                   E^($CellContext`ka$$ $CellContext`\[Tau]$$)) \
$CellContext`ke$$) ((1 + Coth[$CellContext`ke$$ ($CellContext`\[Tau]$$/2)])/(
                  2 $CellContext`ka$$))])/($CellContext`ka$$ - \
$CellContext`ke$$))))) ((($CellContext`c0$$ 
              E^($CellContext`ka$$ $CellContext`\[Tau]$$)) (
              E^($CellContext`ka$$ (($CellContext`ka$$ $CellContext`\[Tau]$$ - 
                  Log[((-1 + 
                    E^($CellContext`ka$$ $CellContext`\[Tau]$$)) \
$CellContext`ke$$) ((1 + Coth[$CellContext`ke$$ ($CellContext`\[Tau]$$/2)])/(
                    2 $CellContext`ka$$))])/($CellContext`ka$$ - \
$CellContext`ke$$))) - 
              E^($CellContext`ke$$ (($CellContext`ka$$ $CellContext`\[Tau]$$ - 
                 Log[((-1 + 
                    E^($CellContext`ka$$ $CellContext`\[Tau]$$)) \
$CellContext`ke$$) ((1 + Coth[$CellContext`ke$$ ($CellContext`\[Tau]$$/2)])/(
                   2 $CellContext`ka$$))])/($CellContext`ka$$ - \
$CellContext`ke$$))))) ($CellContext`ka$$/(-1 + 
             E^($CellContext`ka$$ $CellContext`\[Tau]$$))) - ((((1/
               2) $CellContext`c0$$) 
             E^($CellContext`ka$$ (($CellContext`ka$$ $CellContext`\[Tau]$$ - 
                 Log[((-1 + 
                    E^($CellContext`ka$$ $CellContext`\[Tau]$$)) \
$CellContext`ke$$) ((1 + Coth[$CellContext`ke$$ ($CellContext`\[Tau]$$/2)])/(
                   2 $CellContext`ka$$))])/($CellContext`ka$$ - \
$CellContext`ke$$)))) $CellContext`ka$$) (
            Coth[$CellContext`ka$$ ($CellContext`\[Tau]$$/2)] - 
            Coth[$CellContext`ke$$ ($CellContext`\[Tau]$$/2)])); Row[{
           Grid[{{"\!\(\*SubscriptBox[\(c\), \(1, min\)]\)=", 
              N[$CellContext`c1min, 3]}, {
             "\!\(\*SubscriptBox[\(c\), \(1, max\)]\)=", 
              N[$CellContext`c1max, 3]}, {
             "\!\(\*SubscriptBox[\(c\), \(2, min\)]\)=", 
              N[$CellContext`c2min, 3]}, {
             "\!\(\*SubscriptBox[\(c\), \(2, max\)]\)=", 
              N[$CellContext`c2max, 3]}}], 
           Spacer[20], 
           GraphicsColumn[{
             Plot[{
               
               Part[$CellContext`c12all, 
                1], $CellContext`c1min, $CellContext`c1max}, {$CellContext`t, 
               0, $CellContext`T$$}, PlotRange -> {0, 2}, PlotPoints -> 
              Automatic, ImageSize -> {250, 170}], 
             Plot[{
               
               Part[$CellContext`c12all, 
                2], $CellContext`c2min, $CellContext`c2max}, {$CellContext`t, 
               0, $CellContext`T$$}, PlotRange -> {0, 2}, PlotPoints -> 
              Automatic, Exclusions -> Automatic]}]}]], 
      "Specifications" :> {{{$CellContext`ka$$, 1, 
          "\!\(\*SubscriptBox[\(k\), \(a\)]\)"}, 0.01, 
         2}, {{$CellContext`ke$$, 0.5, "\!\(\*SubscriptBox[\(k\), \(e\)]\)"}, 
         0.005, 
         Dynamic[$CellContext`ka$$ - 0.01]}, 
        "First dose", {{$CellContext`c00$$, 0, 
          "\!\(\*SubscriptBox[\(c\), \(1, 0\)]\)"}, 0, 2}, 
        "Repeated doses", {$CellContext`\[Tau]$$, 1, 
         8}, {{$CellContext`c0$$, 0, "\!\(\*SubscriptBox[\(c\), \(0\)]\)"}, 0,
          2}, {{$CellContext`T$$, 10}, 1, 20}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{651., {255., 260.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.423499905490336*^9, 3.4235000676835585`*^9, 3.423500284815779*^9, 
   3.4235003315229406`*^9, 3.423501703746101*^9, 3.423501754198648*^9, 
   3.423501887069707*^9, 3.4235020050894113`*^9, 3.4235020486220083`*^9, 
   3.4235020998356495`*^9, 3.4235022033845453`*^9, 3.423502295126464*^9, 
   3.4235023390996943`*^9, 3.4235024988794465`*^9, 3.4235025767614355`*^9, 
   3.4235028590273137`*^9, 3.4235029139462833`*^9, 3.4235029869112015`*^9, {
   3.4235030661751776`*^9, 3.42350310535151*^9}, 3.423503137307461*^9, 
   3.4235031920361567`*^9, {3.4235033080329523`*^9, 3.4235033363336463`*^9}, 
   3.4240216884455833`*^9, 3.4240217349624715`*^9, 3.424021831551359*^9, {
   3.4240219560303516`*^9, 3.4240219575124826`*^9}, 3.4240221669336157`*^9, 
   3.424022204677889*^9, 3.4240223594704695`*^9, 3.4240226237004137`*^9, 
   3.424022732086265*^9, 3.4240827963815374`*^9, 3.424082876266406*^9, 
   3.4240834516938305`*^9, 3.4276884605627313`*^9, {3.4276885277793837`*^9, 
   3.427688555188797*^9}},
 CellID->60527244]
}, {2}]],

Cell[CellGroupData[{

Cell["Description", "Section",
 CellChangeTimes->{{3.4559897851875*^9, 3.455989790390625*^9}}],

Cell["\<\
The user can study a two-compartment model of repeated drug dosing described \
by the impulsive system:\
\>", "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4240192663728137`*^9, 3.4240193173861675`*^9}, {
   3.4240823075786734`*^9, 3.424082315830539*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], "'"}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["k", "a"]}], 
     SubscriptBox["c", "1"], " "}]}], TraditionalForm]], "InlineMath"],
 " if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "\[NotEqual]", 
    RowBox[{"n", " ", "\[Tau]"}]}], TraditionalForm]], "InlineMath"],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], "(", 
     RowBox[{
      RowBox[{"n", " ", "\[Tau]"}], "+", "0"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], "(", 
      RowBox[{
       RowBox[{"n", " ", "\[Tau]"}], "-", "0"}], ")"}], "+", 
     SubscriptBox["c", "0"]}]}], TraditionalForm]], "InlineMath"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", "1"}], ",", " ", "2", ",", " ", "..."}], 
    ")"}], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], "(", "0", ")"}], "=", 
    SubscriptBox["c", 
     RowBox[{"1", ",", "0"}]]}], TraditionalForm]], "InlineMath"],
 " "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424019328552223*^9, 3.4240195879852695`*^9}, {
   3.4240823736236415`*^9, 3.4240824262693424`*^9}},
 CellID->648775985],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "2"], "'"}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "a"], 
      SubscriptBox["c", "1"]}], " ", "-", 
     RowBox[{
      SubscriptBox["k", "e"], 
      SubscriptBox["c", "e"], " "}]}]}], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "2"], "(", "0", ")"}], "=", "0"}], TraditionalForm]], 
  "InlineMath"],
 " "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424019328552223*^9, 3.4240195879852695`*^9}, {
   3.4240823736236415`*^9, 3.424082485624691*^9}},
 CellID->404419193],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "1"], "(", "t", ")"}], TraditionalForm]], "InlineMath"],
 " is the concentration of the drug in the stomach depending on the time, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "a"], TraditionalForm]], "InlineMath"],
 " is the rate of absorption, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", 
    RowBox[{"1", ",", "0"}]], TraditionalForm]], "InlineMath"],
 " is the first dose, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "0"], TraditionalForm]], "InlineMath"],
 " is the repeated dose, \[Tau] is the time between the doses. FInally, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "2"], "(", "t", ")"}], TraditionalForm]], "InlineMath"],
 " is the concentration in the blood, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", 
     RowBox[{"e", " "}]], "(", 
    RowBox[{"<", 
     SubscriptBox["k", "a"]}], ")"}], TraditionalForm]], "InlineMath"],
 " is the rate of elimination ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", 
    RowBox[{"i", ",", "min"}]], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", 
    RowBox[{"i", ",", "max"}]], TraditionalForm]], "InlineMath"],
 " are the extremal values of the concentrations at the asymtotically stable \
periodic equilibrium."
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4240195902985964`*^9, 3.424019717281188*^9}, {
   3.4240197613745914`*^9, 3.424019783366214*^9}, {3.424019820299321*^9, 
   3.4240198829894648`*^9}, {3.42408251168216*^9, 3.424082602883301*^9}, {
   3.424082735824461*^9, 3.4240827427544255`*^9}, {3.4240829834805727`*^9, 
   3.4240830876002893`*^9}},
 CellID->143509364]
}, Open  ]],

Cell[CellGroupData[{

Cell["Details", "Section",
 CellChangeTimes->{{3.455989799109375*^9, 3.45598980034375*^9}}],

Cell[TextData[{
 "The explicite formulas ar obtained by solving the given impulsive system. \
In the practice,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", 
    RowBox[{"i", ",", "min"}]], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", 
    RowBox[{"i", ",", "max"}]], TraditionalForm]], "InlineMath"],
 " must be inside the so called region of therapy to avoid over- and \
underdosing. "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424020504933777*^9, 3.4240205345063*^9}, {
   3.4240836512107215`*^9, 3.424083655767274*^9}},
 CellID->616437312]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{777, 566},
WindowMargins->{{55, Automatic}, {Automatic, 7}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 110, 3, 77, "Subtitle"],
Cell[CellGroupData[{
Cell[702, 29, 17933, 409, 1175, "Input",
 CellID->410492984],
Cell[18638, 440, 9844, 183, 532, "Output",
 CellID->60527244]
}, {2}]],
Cell[CellGroupData[{
Cell[28516, 628, 94, 1, 71, "Section"],
Cell[28613, 631, 273, 6, 29, "Text"],
Cell[28889, 639, 1325, 49, 31, "Text",
 CellID->648775985],
Cell[30217, 690, 666, 25, 29, "Text",
 CellID->404419193],
Cell[30886, 717, 1732, 51, 71, "Text",
 CellID->143509364]
}, Open  ]],
Cell[CellGroupData[{
Cell[32655, 773, 91, 1, 71, "Section"],
Cell[32749, 776, 610, 18, 49, "Text",
 CellID->616437312]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
